from pwnlib.constants.constant import Constant
__NR_exit = Constant('__NR_exit',1)
__NR_fork = Constant('__NR_fork',2)
__NR_read = Constant('__NR_read',3)
__NR_write = Constant('__NR_write',4)
__NR_open = Constant('__NR_open',5)
__NR_close = Constant('__NR_close',6)
__NR_waitpid = Constant('__NR_waitpid',7)
__NR_creat = Constant('__NR_creat',8)
__NR_link = Constant('__NR_link',9)
__NR_unlink = Constant('__NR_unlink',10)
__NR_execve = Constant('__NR_execve',11)
__NR_chdir = Constant('__NR_chdir',12)
__NR_time = Constant('__NR_time',13)
__NR_mknod = Constant('__NR_mknod',14)
__NR_chmod = Constant('__NR_chmod',15)
__NR_lchown = Constant('__NR_lchown',16)
__NR_break = Constant('__NR_break',17)
__NR_oldstat = Constant('__NR_oldstat',18)
__NR_lseek = Constant('__NR_lseek',19)
__NR_getpid = Constant('__NR_getpid',20)
__NR_mount = Constant('__NR_mount',21)
__NR_umount = Constant('__NR_umount',22)
__NR_setuid = Constant('__NR_setuid',23)
__NR_getuid = Constant('__NR_getuid',24)
__NR_stime = Constant('__NR_stime',25)
__NR_ptrace = Constant('__NR_ptrace',26)
__NR_alarm = Constant('__NR_alarm',27)
__NR_oldfstat = Constant('__NR_oldfstat',28)
__NR_pause = Constant('__NR_pause',29)
__NR_utime = Constant('__NR_utime',30)
__NR_stty = Constant('__NR_stty',31)
__NR_gtty = Constant('__NR_gtty',32)
__NR_access = Constant('__NR_access',33)
__NR_nice = Constant('__NR_nice',34)
__NR_ftime = Constant('__NR_ftime',35)
__NR_sync = Constant('__NR_sync',36)
__NR_kill = Constant('__NR_kill',37)
__NR_rename = Constant('__NR_rename',38)
__NR_mkdir = Constant('__NR_mkdir',39)
__NR_rmdir = Constant('__NR_rmdir',40)
__NR_dup = Constant('__NR_dup',41)
__NR_pipe = Constant('__NR_pipe',42)
__NR_times = Constant('__NR_times',43)
__NR_prof = Constant('__NR_prof',44)
__NR_brk = Constant('__NR_brk',45)
__NR_setgid = Constant('__NR_setgid',46)
__NR_getgid = Constant('__NR_getgid',47)
__NR_signal = Constant('__NR_signal',48)
__NR_geteuid = Constant('__NR_geteuid',49)
__NR_getegid = Constant('__NR_getegid',50)
__NR_acct = Constant('__NR_acct',51)
__NR_umount2 = Constant('__NR_umount2',52)
__NR_lock = Constant('__NR_lock',53)
__NR_ioctl = Constant('__NR_ioctl',54)
__NR_fcntl = Constant('__NR_fcntl',55)
__NR_mpx = Constant('__NR_mpx',56)
__NR_setpgid = Constant('__NR_setpgid',57)
__NR_ulimit = Constant('__NR_ulimit',58)
__NR_oldolduname = Constant('__NR_oldolduname',59)
__NR_umask = Constant('__NR_umask',60)
__NR_chroot = Constant('__NR_chroot',61)
__NR_ustat = Constant('__NR_ustat',62)
__NR_dup2 = Constant('__NR_dup2',63)
__NR_getppid = Constant('__NR_getppid',64)
__NR_getpgrp = Constant('__NR_getpgrp',65)
__NR_setsid = Constant('__NR_setsid',66)
__NR_sigaction = Constant('__NR_sigaction',67)
__NR_sgetmask = Constant('__NR_sgetmask',68)
__NR_ssetmask = Constant('__NR_ssetmask',69)
__NR_setreuid = Constant('__NR_setreuid',70)
__NR_setregid = Constant('__NR_setregid',71)
__NR_sigsuspend = Constant('__NR_sigsuspend',72)
__NR_sigpending = Constant('__NR_sigpending',73)
__NR_sethostname = Constant('__NR_sethostname',74)
__NR_setrlimit = Constant('__NR_setrlimit',75)
__NR_getrlimit = Constant('__NR_getrlimit',76)
__NR_getrusage = Constant('__NR_getrusage',77)
__NR_gettimeofday = Constant('__NR_gettimeofday',78)
__NR_settimeofday = Constant('__NR_settimeofday',79)
__NR_getgroups = Constant('__NR_getgroups',80)
__NR_setgroups = Constant('__NR_setgroups',81)
__NR_select = Constant('__NR_select',82)
__NR_symlink = Constant('__NR_symlink',83)
__NR_oldlstat = Constant('__NR_oldlstat',84)
__NR_readlink = Constant('__NR_readlink',85)
__NR_uselib = Constant('__NR_uselib',86)
__NR_swapon = Constant('__NR_swapon',87)
__NR_reboot = Constant('__NR_reboot',88)
__NR_readdir = Constant('__NR_readdir',89)
__NR_mmap = Constant('__NR_mmap',90)
__NR_munmap = Constant('__NR_munmap',91)
__NR_truncate = Constant('__NR_truncate',92)
__NR_ftruncate = Constant('__NR_ftruncate',93)
__NR_fchmod = Constant('__NR_fchmod',94)
__NR_fchown = Constant('__NR_fchown',95)
__NR_getpriority = Constant('__NR_getpriority',96)
__NR_setpriority = Constant('__NR_setpriority',97)
__NR_profil = Constant('__NR_profil',98)
__NR_statfs = Constant('__NR_statfs',99)
__NR_fstatfs = Constant('__NR_fstatfs',100)
__NR_ioperm = Constant('__NR_ioperm',101)
__NR_socketcall = Constant('__NR_socketcall',102)
__NR_syslog = Constant('__NR_syslog',103)
__NR_setitimer = Constant('__NR_setitimer',104)
__NR_getitimer = Constant('__NR_getitimer',105)
__NR_stat = Constant('__NR_stat',106)
__NR_lstat = Constant('__NR_lstat',107)
__NR_fstat = Constant('__NR_fstat',108)
__NR_olduname = Constant('__NR_olduname',109)
__NR_iopl = Constant('__NR_iopl',110)
__NR_vhangup = Constant('__NR_vhangup',111)
__NR_idle = Constant('__NR_idle',112)
__NR_vm86old = Constant('__NR_vm86old',113)
__NR_wait4 = Constant('__NR_wait4',114)
__NR_swapoff = Constant('__NR_swapoff',115)
__NR_sysinfo = Constant('__NR_sysinfo',116)
__NR_ipc = Constant('__NR_ipc',117)
__NR_fsync = Constant('__NR_fsync',118)
__NR_sigreturn = Constant('__NR_sigreturn',119)
__NR_clone = Constant('__NR_clone',120)
__NR_setdomainname = Constant('__NR_setdomainname',121)
__NR_uname = Constant('__NR_uname',122)
__NR_modify_ldt = Constant('__NR_modify_ldt',123)
__NR_adjtimex = Constant('__NR_adjtimex',124)
__NR_mprotect = Constant('__NR_mprotect',125)
__NR_sigprocmask = Constant('__NR_sigprocmask',126)
__NR_create_module = Constant('__NR_create_module',127)
__NR_init_module = Constant('__NR_init_module',128)
__NR_delete_module = Constant('__NR_delete_module',129)
__NR_get_kernel_syms = Constant('__NR_get_kernel_syms',130)
__NR_quotactl = Constant('__NR_quotactl',131)
__NR_getpgid = Constant('__NR_getpgid',132)
__NR_fchdir = Constant('__NR_fchdir',133)
__NR_bdflush = Constant('__NR_bdflush',134)
__NR_sysfs = Constant('__NR_sysfs',135)
__NR_personality = Constant('__NR_personality',136)
__NR_afs_syscall = Constant('__NR_afs_syscall',137)
__NR_setfsuid = Constant('__NR_setfsuid',138)
__NR_setfsgid = Constant('__NR_setfsgid',139)
__NR__llseek = Constant('__NR__llseek',140)
__NR_getdents = Constant('__NR_getdents',141)
__NR__newselect = Constant('__NR__newselect',142)
__NR_flock = Constant('__NR_flock',143)
__NR_msync = Constant('__NR_msync',144)
__NR_readv = Constant('__NR_readv',145)
__NR_writev = Constant('__NR_writev',146)
__NR_getsid = Constant('__NR_getsid',147)
__NR_fdatasync = Constant('__NR_fdatasync',148)
__NR__sysctl = Constant('__NR__sysctl',149)
__NR_mlock = Constant('__NR_mlock',150)
__NR_munlock = Constant('__NR_munlock',151)
__NR_mlockall = Constant('__NR_mlockall',152)
__NR_munlockall = Constant('__NR_munlockall',153)
__NR_sched_setparam = Constant('__NR_sched_setparam',154)
__NR_sched_getparam = Constant('__NR_sched_getparam',155)
__NR_sched_setscheduler = Constant('__NR_sched_setscheduler',156)
__NR_sched_getscheduler = Constant('__NR_sched_getscheduler',157)
__NR_sched_yield = Constant('__NR_sched_yield',158)
__NR_sched_get_priority_max = Constant('__NR_sched_get_priority_max',159)
__NR_sched_get_priority_min = Constant('__NR_sched_get_priority_min',160)
__NR_sched_rr_get_interval = Constant('__NR_sched_rr_get_interval',161)
__NR_nanosleep = Constant('__NR_nanosleep',162)
__NR_mremap = Constant('__NR_mremap',163)
__NR_setresuid = Constant('__NR_setresuid',164)
__NR_getresuid = Constant('__NR_getresuid',165)
__NR_vm86 = Constant('__NR_vm86',166)
__NR_query_module = Constant('__NR_query_module',167)
__NR_poll = Constant('__NR_poll',168)
__NR_nfsservctl = Constant('__NR_nfsservctl',169)
__NR_setresgid = Constant('__NR_setresgid',170)
__NR_getresgid = Constant('__NR_getresgid',171)
__NR_prctl = Constant('__NR_prctl',172)
__NR_rt_sigreturn = Constant('__NR_rt_sigreturn',173)
__NR_rt_sigaction = Constant('__NR_rt_sigaction',174)
__NR_rt_sigprocmask = Constant('__NR_rt_sigprocmask',175)
__NR_rt_sigpending = Constant('__NR_rt_sigpending',176)
__NR_rt_sigtimedwait = Constant('__NR_rt_sigtimedwait',177)
__NR_rt_sigqueueinfo = Constant('__NR_rt_sigqueueinfo',178)
__NR_rt_sigsuspend = Constant('__NR_rt_sigsuspend',179)
__NR_pread = Constant('__NR_pread',180)
__NR_pwrite = Constant('__NR_pwrite',181)
__NR_chown = Constant('__NR_chown',182)
__NR_getcwd = Constant('__NR_getcwd',183)
__NR_capget = Constant('__NR_capget',184)
__NR_capset = Constant('__NR_capset',185)
__NR_sigaltstack = Constant('__NR_sigaltstack',186)
__NR_sendfile = Constant('__NR_sendfile',187)
__NR_getpmsg = Constant('__NR_getpmsg',188)
__NR_putpmsg = Constant('__NR_putpmsg',189)
__NR_vfork = Constant('__NR_vfork',190)
__NR_ugetrlimit = Constant('__NR_ugetrlimit',191)
__NR_mmap2 = Constant('__NR_mmap2',192)
__NR_truncate64 = Constant('__NR_truncate64',193)
__NR_ftruncate64 = Constant('__NR_ftruncate64',194)
__NR_stat64 = Constant('__NR_stat64',195)
__NR_lstat64 = Constant('__NR_lstat64',196)
__NR_fstat64 = Constant('__NR_fstat64',197)
__NR_lchown32 = Constant('__NR_lchown32',198)
__NR_getuid32 = Constant('__NR_getuid32',199)
__NR_getgid32 = Constant('__NR_getgid32',200)
__NR_geteuid32 = Constant('__NR_geteuid32',201)
__NR_getegid32 = Constant('__NR_getegid32',202)
__NR_setreuid32 = Constant('__NR_setreuid32',203)
__NR_setregid32 = Constant('__NR_setregid32',204)
__NR_getgroups32 = Constant('__NR_getgroups32',205)
__NR_setgroups32 = Constant('__NR_setgroups32',206)
__NR_fchown32 = Constant('__NR_fchown32',207)
__NR_setresuid32 = Constant('__NR_setresuid32',208)
__NR_getresuid32 = Constant('__NR_getresuid32',209)
__NR_setresgid32 = Constant('__NR_setresgid32',210)
__NR_getresgid32 = Constant('__NR_getresgid32',211)
__NR_chown32 = Constant('__NR_chown32',212)
__NR_setuid32 = Constant('__NR_setuid32',213)
__NR_setgid32 = Constant('__NR_setgid32',214)
__NR_setfsuid32 = Constant('__NR_setfsuid32',215)
__NR_setfsgid32 = Constant('__NR_setfsgid32',216)
__NR_pivot_root = Constant('__NR_pivot_root',217)
__NR_mincore = Constant('__NR_mincore',218)
__NR_madvise = Constant('__NR_madvise',219)
__NR_madvise1 = Constant('__NR_madvise1',219)
__NR_getdents64 = Constant('__NR_getdents64',220)
__NR_fcntl64 = Constant('__NR_fcntl64',221)
__NR_gettid = Constant('__NR_gettid',224)
__NR_readahead = Constant('__NR_readahead',225)
__NR_setxattr = Constant('__NR_setxattr',226)
__NR_lsetxattr = Constant('__NR_lsetxattr',227)
__NR_fsetxattr = Constant('__NR_fsetxattr',228)
__NR_getxattr = Constant('__NR_getxattr',229)
__NR_lgetxattr = Constant('__NR_lgetxattr',230)
__NR_fgetxattr = Constant('__NR_fgetxattr',231)
__NR_listxattr = Constant('__NR_listxattr',232)
__NR_llistxattr = Constant('__NR_llistxattr',233)
__NR_flistxattr = Constant('__NR_flistxattr',234)
__NR_removexattr = Constant('__NR_removexattr',235)
__NR_lremovexattr = Constant('__NR_lremovexattr',236)
__NR_fremovexattr = Constant('__NR_fremovexattr',237)
__NR_tkill = Constant('__NR_tkill',238)
__NR_sendfile64 = Constant('__NR_sendfile64',239)
__NR_futex = Constant('__NR_futex',240)
__NR_sched_setaffinity = Constant('__NR_sched_setaffinity',241)
__NR_sched_getaffinity = Constant('__NR_sched_getaffinity',242)
__NR_set_thread_area = Constant('__NR_set_thread_area',243)
__NR_get_thread_area = Constant('__NR_get_thread_area',244)
__NR_io_setup = Constant('__NR_io_setup',245)
__NR_io_destroy = Constant('__NR_io_destroy',246)
__NR_io_getevents = Constant('__NR_io_getevents',247)
__NR_io_submit = Constant('__NR_io_submit',248)
__NR_io_cancel = Constant('__NR_io_cancel',249)
__NR_fadvise64 = Constant('__NR_fadvise64',250)
__NR_exit_group = Constant('__NR_exit_group',252)
__NR_lookup_dcookie = Constant('__NR_lookup_dcookie',253)
__NR_epoll_create = Constant('__NR_epoll_create',254)
__NR_epoll_ctl = Constant('__NR_epoll_ctl',255)
__NR_epoll_wait = Constant('__NR_epoll_wait',256)
__NR_remap_file_pages = Constant('__NR_remap_file_pages',257)
__NR_set_tid_address = Constant('__NR_set_tid_address',258)
__NR_timer_create = Constant('__NR_timer_create',259)
__NR_timer_settime = Constant('__NR_timer_settime',(259+1))
__NR_timer_gettime = Constant('__NR_timer_gettime',(259+2))
__NR_timer_getoverrun = Constant('__NR_timer_getoverrun',(259+3))
__NR_timer_delete = Constant('__NR_timer_delete',(259+4))
__NR_clock_settime = Constant('__NR_clock_settime',(259+5))
__NR_clock_gettime = Constant('__NR_clock_gettime',(259+6))
__NR_clock_getres = Constant('__NR_clock_getres',(259+7))
__NR_clock_nanosleep = Constant('__NR_clock_nanosleep',(259+8))
__NR_statfs64 = Constant('__NR_statfs64',268)
__NR_fstatfs64 = Constant('__NR_fstatfs64',269)
__NR_tgkill = Constant('__NR_tgkill',270)
__NR_utimes = Constant('__NR_utimes',271)
__NR_fadvise64_64 = Constant('__NR_fadvise64_64',272)
__NR_vserver = Constant('__NR_vserver',273)
__NR_mbind = Constant('__NR_mbind',274)
__NR_get_mempolicy = Constant('__NR_get_mempolicy',275)
__NR_set_mempolicy = Constant('__NR_set_mempolicy',276)
__NR_mq_open = Constant('__NR_mq_open',277)
__NR_mq_unlink = Constant('__NR_mq_unlink',(277+1))
__NR_mq_timedsend = Constant('__NR_mq_timedsend',(277+2))
__NR_mq_timedreceive = Constant('__NR_mq_timedreceive',(277+3))
__NR_mq_notify = Constant('__NR_mq_notify',(277+4))
__NR_mq_getsetattr = Constant('__NR_mq_getsetattr',(277+5))
__NR_sys_kexec_load = Constant('__NR_sys_kexec_load',283)
__NR_waitid = Constant('__NR_waitid',284)
__NR_add_key = Constant('__NR_add_key',286)
__NR_request_key = Constant('__NR_request_key',287)
__NR_keyctl = Constant('__NR_keyctl',288)
__NR_ioprio_set = Constant('__NR_ioprio_set',289)
__NR_ioprio_get = Constant('__NR_ioprio_get',290)
__NR_inotify_init = Constant('__NR_inotify_init',291)
__NR_inotify_add_watch = Constant('__NR_inotify_add_watch',292)
__NR_inotify_rm_watch = Constant('__NR_inotify_rm_watch',293)
__NR_migrate_pages = Constant('__NR_migrate_pages',294)
__NR_openat = Constant('__NR_openat',295)
__NR_mkdirat = Constant('__NR_mkdirat',296)
__NR_mknodat = Constant('__NR_mknodat',297)
__NR_fchownat = Constant('__NR_fchownat',298)
__NR_futimesat = Constant('__NR_futimesat',299)
__NR_fstatat64 = Constant('__NR_fstatat64',300)
__NR_unlinkat = Constant('__NR_unlinkat',301)
__NR_renameat = Constant('__NR_renameat',302)
__NR_linkat = Constant('__NR_linkat',303)
__NR_symlinkat = Constant('__NR_symlinkat',304)
__NR_readlinkat = Constant('__NR_readlinkat',305)
__NR_fchmodat = Constant('__NR_fchmodat',306)
__NR_faccessat = Constant('__NR_faccessat',307)
__NR_pselect6 = Constant('__NR_pselect6',308)
__NR_ppoll = Constant('__NR_ppoll',309)
__NR_unshare = Constant('__NR_unshare',310)
__NR_set_robust_list = Constant('__NR_set_robust_list',311)
__NR_get_robust_list = Constant('__NR_get_robust_list',312)
__NR_splice = Constant('__NR_splice',313)
__NR_sync_file_range = Constant('__NR_sync_file_range',314)
__NR_tee = Constant('__NR_tee',315)
__NR_vmsplice = Constant('__NR_vmsplice',316)
__NR_move_pages = Constant('__NR_move_pages',317)
__NR_getcpu = Constant('__NR_getcpu',318)
__NR_epoll_pwait = Constant('__NR_epoll_pwait',319)
__NR_utimensat = Constant('__NR_utimensat',320)
__NR_signalfd = Constant('__NR_signalfd',321)
__NR_timerfd = Constant('__NR_timerfd',322)
__NR_eventfd = Constant('__NR_eventfd',323)
__NR_fallocate = Constant('__NR_fallocate',324)
__NR_timerfd_settime = Constant('__NR_timerfd_settime',325)
__NR_timerfd_gettime = Constant('__NR_timerfd_gettime',326)
__NR_signalfd4 = Constant('__NR_signalfd4',327)
__NR_eventfd2 = Constant('__NR_eventfd2',328)
__NR_epoll_create1 = Constant('__NR_epoll_create1',329)
__NR_dup3 = Constant('__NR_dup3',330)
__NR_pipe2 = Constant('__NR_pipe2',331)
__NR_inotify_init1 = Constant('__NR_inotify_init1',332)
__NR_preadv = Constant('__NR_preadv',333)
__NR_pwritev = Constant('__NR_pwritev',334)
__NR_rt_tgsigqueueinfo = Constant('__NR_rt_tgsigqueueinfo',335)
__NR_perf_event_open = Constant('__NR_perf_event_open',336)
__NR_recvmmsg = Constant('__NR_recvmmsg',337)
__NR_fanotify_init = Constant('__NR_fanotify_init',338)
__NR_fanotify_mark = Constant('__NR_fanotify_mark',339)
__NR_prlimit64 = Constant('__NR_prlimit64',340)
__NR_name_to_handle_at = Constant('__NR_name_to_handle_at',341)
__NR_open_by_handle_at = Constant('__NR_open_by_handle_at',342)
__NR_clock_adjtime = Constant('__NR_clock_adjtime',343)
__NR_syncfs = Constant('__NR_syncfs',344)
__NR_sendmmsg = Constant('__NR_sendmmsg',345)
__NR_setns = Constant('__NR_setns',346)
__NR_process_vm_readv = Constant('__NR_process_vm_readv',347)
__NR_process_vm_writev = Constant('__NR_process_vm_writev',348)
__NR_kcmp = Constant('__NR_kcmp',349)
__NR_finit_module = Constant('__NR_finit_module',350)
__NR_sched_setattr = Constant('__NR_sched_setattr',351)
__NR_sched_getattr = Constant('__NR_sched_getattr',352)
__NR_renameat2 = Constant('__NR_renameat2',353)
__NR_seccomp = Constant('__NR_seccomp',354)
__NR_getrandom = Constant('__NR_getrandom',355)
__NR_memfd_create = Constant('__NR_memfd_create',356)
__NR_bpf = Constant('__NR_bpf',357)
__NR_execveat = Constant('__NR_execveat',358)
__NR_socket = Constant('__NR_socket',359)
__NR_socketpair = Constant('__NR_socketpair',360)
__NR_bind = Constant('__NR_bind',361)
__NR_connect = Constant('__NR_connect',362)
__NR_listen = Constant('__NR_listen',363)
__NR_accept4 = Constant('__NR_accept4',364)
__NR_getsockopt = Constant('__NR_getsockopt',365)
__NR_setsockopt = Constant('__NR_setsockopt',366)
__NR_getsockname = Constant('__NR_getsockname',367)
__NR_getpeername = Constant('__NR_getpeername',368)
__NR_sendto = Constant('__NR_sendto',369)
__NR_sendmsg = Constant('__NR_sendmsg',370)
__NR_recvfrom = Constant('__NR_recvfrom',371)
__NR_recvmsg = Constant('__NR_recvmsg',372)
__NR_shutdown = Constant('__NR_shutdown',373)
__NR_userfaultfd = Constant('__NR_userfaultfd',374)
__NR_membarrier = Constant('__NR_membarrier',375)
__NR_mlock2 = Constant('__NR_mlock2',376)
__NR_copy_file_range = Constant('__NR_copy_file_range',377)
__NR_preadv2 = Constant('__NR_preadv2',378)
__NR_pwritev2 = Constant('__NR_pwritev2',379)
__NR_pkey_mprotect = Constant('__NR_pkey_mprotect',380)
__NR_pkey_alloc = Constant('__NR_pkey_alloc',381)
__NR_pkey_free = Constant('__NR_pkey_free',382)
__NR_ia32_statx = Constant('__NR_ia32_statx',383)
__NR_ia32_arch_prctl = Constant('__NR_ia32_arch_prctl',384)
__NR_ia32_io_pgetevents = Constant('__NR_ia32_io_pgetevents',385)
__NR_ia32_rseq = Constant('__NR_ia32_rseq',386)
__NR_semget = Constant('__NR_semget',393)
__NR_semctl = Constant('__NR_semctl',394)
__NR_shmget = Constant('__NR_shmget',395)
__NR_shmctl = Constant('__NR_shmctl',396)
__NR_shmat = Constant('__NR_shmat',397)
__NR_shmdt = Constant('__NR_shmdt',398)
__NR_msgget = Constant('__NR_msgget',399)
__NR_msgsnd = Constant('__NR_msgsnd',400)
__NR_msgrcv = Constant('__NR_msgrcv',401)
__NR_msgctl = Constant('__NR_msgctl',402)
__NR_clock_gettime64 = Constant('__NR_clock_gettime64',403)
__NR_clock_settime64 = Constant('__NR_clock_settime64',404)
__NR_clock_adjtime64 = Constant('__NR_clock_adjtime64',405)
__NR_clock_getres_time64 = Constant('__NR_clock_getres_time64',406)
__NR_clock_nanosleep_time64 = Constant('__NR_clock_nanosleep_time64',407)
__NR_timer_gettime64 = Constant('__NR_timer_gettime64',408)
__NR_timer_settime64 = Constant('__NR_timer_settime64',409)
__NR_timerfd_gettime64 = Constant('__NR_timerfd_gettime64',410)
__NR_timerfd_settime64 = Constant('__NR_timerfd_settime64',411)
__NR_utimensat_time64 = Constant('__NR_utimensat_time64',412)
__NR_pselect6_time64 = Constant('__NR_pselect6_time64',413)
__NR_ppoll_time64 = Constant('__NR_ppoll_time64',414)
__NR_io_pgetevents_time64 = Constant('__NR_io_pgetevents_time64',416)
__NR_recvmmsg_time64 = Constant('__NR_recvmmsg_time64',417)
__NR_mq_timedsend_time64 = Constant('__NR_mq_timedsend_time64',418)
__NR_mq_timedreceive_time64 = Constant('__NR_mq_timedreceive_time64',419)
__NR_semtimedop_time64 = Constant('__NR_semtimedop_time64',420)
__NR_rt_sigtimedwait_time64 = Constant('__NR_rt_sigtimedwait_time64',421)
__NR_futex_time64 = Constant('__NR_futex_time64',422)
__NR_sched_rr_get_interval_time64 = Constant('__NR_sched_rr_get_interval_time64',423)
__NR_pidfd_send_signal = Constant('__NR_pidfd_send_signal',424)
__NR_io_uring_setup = Constant('__NR_io_uring_setup',425)
__NR_io_uring_enter = Constant('__NR_io_uring_enter',426)
__NR_io_uring_register = Constant('__NR_io_uring_register',427)
__NR_open_tree = Constant('__NR_open_tree',428)
__NR_move_mount = Constant('__NR_move_mount',429)
__NR_fsopen = Constant('__NR_fsopen',430)
__NR_fsconfig = Constant('__NR_fsconfig',431)
__NR_fsmount = Constant('__NR_fsmount',432)
__NR_fspick = Constant('__NR_fspick',433)
__NR_pidfd_open = Constant('__NR_pidfd_open',434)
__NR_clone3 = Constant('__NR_clone3',435)
__NR_openat2 = Constant('__NR_openat2',437)
__NR_pidfd_getfd = Constant('__NR_pidfd_getfd',438)
SYS_SOCKET = Constant('SYS_SOCKET',1)
SYS_BIND = Constant('SYS_BIND',2)
SYS_CONNECT = Constant('SYS_CONNECT',3)
SYS_LISTEN = Constant('SYS_LISTEN',4)
SYS_ACCEPT = Constant('SYS_ACCEPT',5)
SYS_GETSOCKNAME = Constant('SYS_GETSOCKNAME',6)
SYS_GETPEERNAME = Constant('SYS_GETPEERNAME',7)
SYS_SOCKETPAIR = Constant('SYS_SOCKETPAIR',8)
SYS_SEND = Constant('SYS_SEND',9)
SYS_RECV = Constant('SYS_RECV',10)
SYS_SENDTO = Constant('SYS_SENDTO',11)
SYS_RECVFROM = Constant('SYS_RECVFROM',12)
SYS_SHUTDOWN = Constant('SYS_SHUTDOWN',13)
SYS_SETSOCKOPT = Constant('SYS_SETSOCKOPT',14)
SYS_GETSOCKOPT = Constant('SYS_GETSOCKOPT',15)
SYS_SENDMSG = Constant('SYS_SENDMSG',16)
SYS_RECVMSG = Constant('SYS_RECVMSG',17)
MAP_32BIT = Constant('MAP_32BIT',0x40)
INADDR_ANY = Constant('INADDR_ANY',0)
INADDR_BROADCAST = Constant('INADDR_BROADCAST',0xffffffff)
INADDR_NONE = Constant('INADDR_NONE',0xffffffff)
INADDR_LOOPBACK = Constant('INADDR_LOOPBACK',0x7f000001)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EAGAIN = Constant('EAGAIN',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EDEADLK = Constant('EDEADLK',35)
ENAMETOOLONG = Constant('ENAMETOOLONG',36)
ENOLCK = Constant('ENOLCK',37)
ENOSYS = Constant('ENOSYS',38)
ENOTEMPTY = Constant('ENOTEMPTY',39)
ELOOP = Constant('ELOOP',40)
EWOULDBLOCK = Constant('EWOULDBLOCK',11)
ENOMSG = Constant('ENOMSG',42)
EIDRM = Constant('EIDRM',43)
ECHRNG = Constant('ECHRNG',44)
EL2NSYNC = Constant('EL2NSYNC',45)
EL3HLT = Constant('EL3HLT',46)
EL3RST = Constant('EL3RST',47)
ELNRNG = Constant('ELNRNG',48)
EUNATCH = Constant('EUNATCH',49)
ENOCSI = Constant('ENOCSI',50)
EL2HLT = Constant('EL2HLT',51)
EBADE = Constant('EBADE',52)
EBADR = Constant('EBADR',53)
EXFULL = Constant('EXFULL',54)
ENOANO = Constant('ENOANO',55)
EBADRQC = Constant('EBADRQC',56)
EBADSLT = Constant('EBADSLT',57)
EDEADLOCK = Constant('EDEADLOCK',35)
EBFONT = Constant('EBFONT',59)
ENOSTR = Constant('ENOSTR',60)
ENODATA = Constant('ENODATA',61)
ETIME = Constant('ETIME',62)
ENOSR = Constant('ENOSR',63)
ENONET = Constant('ENONET',64)
ENOPKG = Constant('ENOPKG',65)
EREMOTE = Constant('EREMOTE',66)
ENOLINK = Constant('ENOLINK',67)
EADV = Constant('EADV',68)
ESRMNT = Constant('ESRMNT',69)
ECOMM = Constant('ECOMM',70)
EPROTO = Constant('EPROTO',71)
EMULTIHOP = Constant('EMULTIHOP',72)
EDOTDOT = Constant('EDOTDOT',73)
EBADMSG = Constant('EBADMSG',74)
EOVERFLOW = Constant('EOVERFLOW',75)
ENOTUNIQ = Constant('ENOTUNIQ',76)
EBADFD = Constant('EBADFD',77)
EREMCHG = Constant('EREMCHG',78)
ELIBACC = Constant('ELIBACC',79)
ELIBBAD = Constant('ELIBBAD',80)
ELIBSCN = Constant('ELIBSCN',81)
ELIBMAX = Constant('ELIBMAX',82)
ELIBEXEC = Constant('ELIBEXEC',83)
EILSEQ = Constant('EILSEQ',84)
ERESTART = Constant('ERESTART',85)
ESTRPIPE = Constant('ESTRPIPE',86)
EUSERS = Constant('EUSERS',87)
ENOTSOCK = Constant('ENOTSOCK',88)
EDESTADDRREQ = Constant('EDESTADDRREQ',89)
EMSGSIZE = Constant('EMSGSIZE',90)
EPROTOTYPE = Constant('EPROTOTYPE',91)
ENOPROTOOPT = Constant('ENOPROTOOPT',92)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',93)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',94)
EOPNOTSUPP = Constant('EOPNOTSUPP',95)
ENOTSUP = Constant('ENOTSUP',95)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',96)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',97)
EADDRINUSE = Constant('EADDRINUSE',98)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',99)
ENETDOWN = Constant('ENETDOWN',100)
ENETUNREACH = Constant('ENETUNREACH',101)
ENETRESET = Constant('ENETRESET',102)
ECONNABORTED = Constant('ECONNABORTED',103)
ECONNRESET = Constant('ECONNRESET',104)
ENOBUFS = Constant('ENOBUFS',105)
EISCONN = Constant('EISCONN',106)
ENOTCONN = Constant('ENOTCONN',107)
ESHUTDOWN = Constant('ESHUTDOWN',108)
ETOOMANYREFS = Constant('ETOOMANYREFS',109)
ETIMEDOUT = Constant('ETIMEDOUT',110)
ECONNREFUSED = Constant('ECONNREFUSED',111)
EHOSTDOWN = Constant('EHOSTDOWN',112)
EHOSTUNREACH = Constant('EHOSTUNREACH',113)
EALREADY = Constant('EALREADY',114)
EINPROGRESS = Constant('EINPROGRESS',115)
ESTALE = Constant('ESTALE',116)
EUCLEAN = Constant('EUCLEAN',117)
ENOTNAM = Constant('ENOTNAM',118)
ENAVAIL = Constant('ENAVAIL',119)
EISNAM = Constant('EISNAM',120)
EREMOTEIO = Constant('EREMOTEIO',121)
EDQUOT = Constant('EDQUOT',122)
ENOMEDIUM = Constant('ENOMEDIUM',123)
EMEDIUMTYPE = Constant('EMEDIUMTYPE',124)
ECANCELED = Constant('ECANCELED',125)
ENOKEY = Constant('ENOKEY',126)
EKEYEXPIRED = Constant('EKEYEXPIRED',127)
EKEYREVOKED = Constant('EKEYREVOKED',128)
EKEYREJECTED = Constant('EKEYREJECTED',129)
EOWNERDEAD = Constant('EOWNERDEAD',130)
ENOTRECOVERABLE = Constant('ENOTRECOVERABLE',131)
ERFKILL = Constant('ERFKILL',132)
EHWPOISON = Constant('EHWPOISON',133)
__SYS_NERR = Constant('__SYS_NERR',((133) + 1))
__LITTLE_ENDIAN = Constant('__LITTLE_ENDIAN',1234)
__BIG_ENDIAN = Constant('__BIG_ENDIAN',4321)
__BYTE_ORDER = Constant('__BYTE_ORDER',1234)
__FLOAT_WORD_ORDER = Constant('__FLOAT_WORD_ORDER',1234)
LITTLE_ENDIAN = Constant('LITTLE_ENDIAN',1234)
BIG_ENDIAN = Constant('BIG_ENDIAN',4321)
BYTE_ORDER = Constant('BYTE_ORDER',1234)
__WORDSIZE = Constant('__WORDSIZE',32)
__UNALIGNED_MEMORY_ACCESS_OK = Constant('__UNALIGNED_MEMORY_ACCESS_OK',1)
INT8_MAX = Constant('INT8_MAX',(127))
INT16_MAX = Constant('INT16_MAX',(32767))
INT32_MAX = Constant('INT32_MAX',(2147483647))
INT64_MAX = Constant('INT64_MAX',(9223372036854775807))
INT8_MIN = Constant('INT8_MIN',(-1 - (127)))
INT16_MIN = Constant('INT16_MIN',(-1 - (32767)))
INT32_MIN = Constant('INT32_MIN',(-1 - (2147483647)))
INT64_MIN = Constant('INT64_MIN',(-1 - (9223372036854775807)))
INT_LEAST8_MAX = Constant('INT_LEAST8_MAX',(127))
INT_LEAST8_MIN = Constant('INT_LEAST8_MIN',(-1 - (127)))
INT_LEAST16_MAX = Constant('INT_LEAST16_MAX',(32767))
INT_LEAST16_MIN = Constant('INT_LEAST16_MIN',(-1 - (32767)))
INT_LEAST32_MAX = Constant('INT_LEAST32_MAX',(2147483647))
INT_LEAST32_MIN = Constant('INT_LEAST32_MIN',(-1 - (2147483647)))
INT_LEAST64_MAX = Constant('INT_LEAST64_MAX',(9223372036854775807))
INT_LEAST64_MIN = Constant('INT_LEAST64_MIN',(-1 - (9223372036854775807)))
UINT8_MAX = Constant('UINT8_MAX',0xff)
UINT16_MAX = Constant('UINT16_MAX',0xffff)
UINT32_MAX = Constant('UINT32_MAX',0xffffffff)
UINT64_MAX = Constant('UINT64_MAX',0xffffffffffffffff)
UINT_LEAST8_MAX = Constant('UINT_LEAST8_MAX',0xff)
UINT_LEAST16_MAX = Constant('UINT_LEAST16_MAX',0xffff)
UINT_LEAST32_MAX = Constant('UINT_LEAST32_MAX',0xffffffff)
UINT_LEAST64_MAX = Constant('UINT_LEAST64_MAX',0xffffffffffffffff)
INTPTR_MIN = Constant('INTPTR_MIN',(-1 - (2147483647)))
INTPTR_MAX = Constant('INTPTR_MAX',(2147483647))
UINTPTR_MAX = Constant('UINTPTR_MAX',0xffffffff)
SIZE_MAX = Constant('SIZE_MAX',0xffffffff)
PTRDIFF_MIN = Constant('PTRDIFF_MIN',(-1 - (2147483647)))
PTRDIFF_MAX = Constant('PTRDIFF_MAX',(2147483647))
INTMAX_MIN = Constant('INTMAX_MIN',(-1 - (9223372036854775807)))
INTMAX_MAX = Constant('INTMAX_MAX',(9223372036854775807))
UINTMAX_MAX = Constant('UINTMAX_MAX',0xffffffffffffffff)
INT_FAST8_MIN = Constant('INT_FAST8_MIN',(-1 - (127)))
INT_FAST8_MAX = Constant('INT_FAST8_MAX',(127))
INT_FAST64_MIN = Constant('INT_FAST64_MIN',(-1 - (9223372036854775807)))
INT_FAST64_MAX = Constant('INT_FAST64_MAX',(9223372036854775807))
UINT_FAST8_MAX = Constant('UINT_FAST8_MAX',0xff)
UINT_FAST64_MAX = Constant('UINT_FAST64_MAX',0xffffffffffffffff)
INT_FAST16_MIN = Constant('INT_FAST16_MIN',(-1 - (2147483647)))
INT_FAST16_MAX = Constant('INT_FAST16_MAX',(2147483647))
UINT_FAST16_MAX = Constant('UINT_FAST16_MAX',0xffffffff)
INT_FAST32_MIN = Constant('INT_FAST32_MIN',(-1 - (2147483647)))
INT_FAST32_MAX = Constant('INT_FAST32_MAX',(2147483647))
UINT_FAST32_MAX = Constant('UINT_FAST32_MAX',0xffffffff)
WINT_MIN = Constant('WINT_MIN',0)
__FSUID_H = Constant('__FSUID_H',1)
NSIG = Constant('NSIG',32)
_NSIG = Constant('_NSIG',65)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGIOT = Constant('SIGIOT',6)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGSEGV = Constant('SIGSEGV',11)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGUNUSED = Constant('SIGUNUSED',31)
SIGBUS = Constant('SIGBUS',7)
SIGUSR1 = Constant('SIGUSR1',10)
SIGUSR2 = Constant('SIGUSR2',12)
SIGSTKFLT = Constant('SIGSTKFLT',16)
SIGCHLD = Constant('SIGCHLD',17)
SIGCONT = Constant('SIGCONT',18)
SIGSTOP = Constant('SIGSTOP',19)
SIGTSTP = Constant('SIGTSTP',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGURG = Constant('SIGURG',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGIO = Constant('SIGIO',29)
SIGPWR = Constant('SIGPWR',30)
SIGSYS = Constant('SIGSYS',31)
SIGCLD = Constant('SIGCLD',17)
SIGPOLL = Constant('SIGPOLL',29)
SIGLOST = Constant('SIGLOST',30)
SIGRTMIN = Constant('SIGRTMIN',32)
SIGRTMAX = Constant('SIGRTMAX',(65-1))
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',0x00000001)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x00000002)
SA_SIGINFO = Constant('SA_SIGINFO',0x00000004)
SA_RESTORER = Constant('SA_RESTORER',0x04000000)
SA_ONSTACK = Constant('SA_ONSTACK',0x08000000)
SA_RESTART = Constant('SA_RESTART',0x10000000)
SA_INTERRUPT = Constant('SA_INTERRUPT',0x20000000)
SA_NODEFER = Constant('SA_NODEFER',0x40000000)
SA_RESETHAND = Constant('SA_RESETHAND',0x80000000)
SA_NOMASK = Constant('SA_NOMASK',0x40000000)
SA_ONESHOT = Constant('SA_ONESHOT',0x80000000)
SS_ONSTACK = Constant('SS_ONSTACK',1)
SS_DISABLE = Constant('SS_DISABLE',2)
MINSIGSTKSZ = Constant('MINSIGSTKSZ',2048)
SIGSTKSZ = Constant('SIGSTKSZ',8192)
SIG_BLOCK = Constant('SIG_BLOCK',0)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',1)
SIG_SETMASK = Constant('SIG_SETMASK',2)
SI_MAX_SIZE = Constant('SI_MAX_SIZE',128)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',0)
SIGEV_NONE = Constant('SIGEV_NONE',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',2)
SIGEV_THREAD_ID = Constant('SIGEV_THREAD_ID',4)
SIGEV_MAX_SIZE = Constant('SIGEV_MAX_SIZE',64)
_SYS_TIME_H = Constant('_SYS_TIME_H',1)
ITIMER_REAL = Constant('ITIMER_REAL',0)
ITIMER_VIRTUAL = Constant('ITIMER_VIRTUAL',1)
ITIMER_PROF = Constant('ITIMER_PROF',2)
X86_FXSR_MAGIC = Constant('X86_FXSR_MAGIC',0x0000)
FD_SETSIZE = Constant('FD_SETSIZE',1024)
R_OK = Constant('R_OK',4)
W_OK = Constant('W_OK',2)
X_OK = Constant('X_OK',1)
F_OK = Constant('F_OK',0)
SEEK_SET = Constant('SEEK_SET',0)
SEEK_CUR = Constant('SEEK_CUR',1)
SEEK_END = Constant('SEEK_END',2)
STDIN_FILENO = Constant('STDIN_FILENO',0)
STDOUT_FILENO = Constant('STDOUT_FILENO',1)
STDERR_FILENO = Constant('STDERR_FILENO',2)
_CS_PATH = Constant('_CS_PATH',1)
_SC_CLK_TCK = Constant('_SC_CLK_TCK',1)
_SC_ARG_MAX = Constant('_SC_ARG_MAX',2)
_SC_NGROUPS_MAX = Constant('_SC_NGROUPS_MAX',3)
_SC_OPEN_MAX = Constant('_SC_OPEN_MAX',4)
_SC_PAGESIZE = Constant('_SC_PAGESIZE',5)
_SC_NPROCESSORS_ONLN = Constant('_SC_NPROCESSORS_ONLN',6)
_SC_NPROCESSORS_CONF = Constant('_SC_NPROCESSORS_CONF',6)
_SC_PHYS_PAGES = Constant('_SC_PHYS_PAGES',7)
_SC_GETPW_R_SIZE_MAX = Constant('_SC_GETPW_R_SIZE_MAX',8)
_SC_GETGR_R_SIZE_MAX = Constant('_SC_GETGR_R_SIZE_MAX',9)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',1)
_PC_VDISABLE = Constant('_PC_VDISABLE',2)
L_cuserid = Constant('L_cuserid',17)
_POSIX_VERSION = Constant('_POSIX_VERSION',199506)
F_ULOCK = Constant('F_ULOCK',0)
F_LOCK = Constant('F_LOCK',1)
F_TLOCK = Constant('F_TLOCK',2)
F_TEST = Constant('F_TEST',3)
_POSIX_MAPPED_FILES = Constant('_POSIX_MAPPED_FILES',200809)
STAT64_HAS_BROKEN_ST_INO = Constant('STAT64_HAS_BROKEN_ST_INO',1)
S_IFMT = Constant('S_IFMT',0o0170000)
S_IFSOCK = Constant('S_IFSOCK',0o140000)
S_IFLNK = Constant('S_IFLNK',0o120000)
S_IFREG = Constant('S_IFREG',0o100000)
S_IFBLK = Constant('S_IFBLK',0o060000)
S_IFDIR = Constant('S_IFDIR',0o040000)
S_IFCHR = Constant('S_IFCHR',0o020000)
S_IFIFO = Constant('S_IFIFO',0o010000)
S_ISUID = Constant('S_ISUID',0o004000)
S_ISGID = Constant('S_ISGID',0o002000)
S_ISVTX = Constant('S_ISVTX',0o001000)
S_IRWXU = Constant('S_IRWXU',0o0700)
S_IRUSR = Constant('S_IRUSR',0o0400)
S_IWUSR = Constant('S_IWUSR',0o0200)
S_IXUSR = Constant('S_IXUSR',0o0100)
S_IRWXG = Constant('S_IRWXG',0o0070)
S_IRGRP = Constant('S_IRGRP',0o0040)
S_IWGRP = Constant('S_IWGRP',0o0020)
S_IXGRP = Constant('S_IXGRP',0o0010)
S_IRWXO = Constant('S_IRWXO',0o0007)
S_IROTH = Constant('S_IROTH',0o0004)
S_IWOTH = Constant('S_IWOTH',0o0002)
S_IXOTH = Constant('S_IXOTH',0o0001)
S_IREAD = Constant('S_IREAD',0o0400)
S_IWRITE = Constant('S_IWRITE',0o0200)
S_IEXEC = Constant('S_IEXEC',0o0100)
_SYS_UIO = Constant('_SYS_UIO',1)
SOL_SOCKET = Constant('SOL_SOCKET',1)
SO_DEBUG = Constant('SO_DEBUG',1)
SO_REUSEADDR = Constant('SO_REUSEADDR',2)
SO_TYPE = Constant('SO_TYPE',3)
SO_ERROR = Constant('SO_ERROR',4)
SO_DONTROUTE = Constant('SO_DONTROUTE',5)
SO_BROADCAST = Constant('SO_BROADCAST',6)
SO_SNDBUF = Constant('SO_SNDBUF',7)
SO_RCVBUF = Constant('SO_RCVBUF',8)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',9)
SO_OOBINLINE = Constant('SO_OOBINLINE',10)
SO_NO_CHECK = Constant('SO_NO_CHECK',11)
SO_PRIORITY = Constant('SO_PRIORITY',12)
SO_LINGER = Constant('SO_LINGER',13)
SO_BSDCOMPAT = Constant('SO_BSDCOMPAT',14)
SO_REUSEPORT = Constant('SO_REUSEPORT',15)
SO_PASSCRED = Constant('SO_PASSCRED',16)
SO_PEERCRED = Constant('SO_PEERCRED',17)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',18)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',19)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',20)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',21)
SO_SECURITY_AUTHENTICATION = Constant('SO_SECURITY_AUTHENTICATION',22)
SO_SECURITY_ENCRYPTION_TRANSPORT = Constant('SO_SECURITY_ENCRYPTION_TRANSPORT',23)
SO_SECURITY_ENCRYPTION_NETWORK = Constant('SO_SECURITY_ENCRYPTION_NETWORK',24)
SO_BINDTODEVICE = Constant('SO_BINDTODEVICE',25)
SO_ATTACH_FILTER = Constant('SO_ATTACH_FILTER',26)
SO_DETACH_FILTER = Constant('SO_DETACH_FILTER',27)
SO_GET_FILTER = Constant('SO_GET_FILTER',26)
SO_PEERNAME = Constant('SO_PEERNAME',28)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',29)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',29)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',30)
SO_PEERSEC = Constant('SO_PEERSEC',31)
SO_SNDBUFFORCE = Constant('SO_SNDBUFFORCE',32)
SO_RCVBUFFORCE = Constant('SO_RCVBUFFORCE',33)
SO_PASSSEC = Constant('SO_PASSSEC',34)
SO_TIMESTAMPNS = Constant('SO_TIMESTAMPNS',35)
SCM_TIMESTAMPNS = Constant('SCM_TIMESTAMPNS',35)
SO_MARK = Constant('SO_MARK',36)
SO_TIMESTAMPING = Constant('SO_TIMESTAMPING',37)
SCM_TIMESTAMPING = Constant('SCM_TIMESTAMPING',37)
SO_PROTOCOL = Constant('SO_PROTOCOL',38)
SO_DOMAIN = Constant('SO_DOMAIN',39)
SO_RXQ_OVFL = Constant('SO_RXQ_OVFL',40)
SO_WIFI_STATUS = Constant('SO_WIFI_STATUS',41)
SCM_WIFI_STATUS = Constant('SCM_WIFI_STATUS',41)
SO_PEEK_OFF = Constant('SO_PEEK_OFF',42)
SO_NOFCS = Constant('SO_NOFCS',43)
SO_LOCK_FILTER = Constant('SO_LOCK_FILTER',44)
SO_SELECT_ERR_QUEUE = Constant('SO_SELECT_ERR_QUEUE',45)
SO_BUSY_POLL = Constant('SO_BUSY_POLL',46)
SO_MAX_PACING_RATE = Constant('SO_MAX_PACING_RATE',47)
SO_BPF_EXTENSIONS = Constant('SO_BPF_EXTENSIONS',48)
SO_INCOMING_CPU = Constant('SO_INCOMING_CPU',49)
SO_ATTACH_BPF = Constant('SO_ATTACH_BPF',50)
SO_DETACH_BPF = Constant('SO_DETACH_BPF',27)
SO_ATTACH_REUSEPORT_CBPF = Constant('SO_ATTACH_REUSEPORT_CBPF',51)
SO_ATTACH_REUSEPORT_EBPF = Constant('SO_ATTACH_REUSEPORT_EBPF',52)
SO_CNX_ADVICE = Constant('SO_CNX_ADVICE',53)
SCM_TIMESTAMPING_OPT_STATS = Constant('SCM_TIMESTAMPING_OPT_STATS',54)
SO_MEMINFO = Constant('SO_MEMINFO',55)
SO_INCOMING_NAPI_ID = Constant('SO_INCOMING_NAPI_ID',56)
SO_COOKIE = Constant('SO_COOKIE',57)
SCM_TIMESTAMPING_PKTINFO = Constant('SCM_TIMESTAMPING_PKTINFO',58)
SO_PEERGROUPS = Constant('SO_PEERGROUPS',59)
SO_ZEROCOPY = Constant('SO_ZEROCOPY',60)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SOCK_DCCP = Constant('SOCK_DCCP',6)
SOCK_PACKET = Constant('SOCK_PACKET',10)
UIO_FASTIOV = Constant('UIO_FASTIOV',8)
UIO_MAXIOV = Constant('UIO_MAXIOV',1024)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_CREDENTIALS = Constant('SCM_CREDENTIALS',0x02)
SCM_CONNECT = Constant('SCM_CONNECT',0x03)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_LOCAL = Constant('AF_LOCAL',1)
AF_INET = Constant('AF_INET',2)
AF_AX25 = Constant('AF_AX25',3)
AF_IPX = Constant('AF_IPX',4)
AF_APPLETALK = Constant('AF_APPLETALK',5)
AF_NETROM = Constant('AF_NETROM',6)
AF_BRIDGE = Constant('AF_BRIDGE',7)
AF_ATMPVC = Constant('AF_ATMPVC',8)
AF_X25 = Constant('AF_X25',9)
AF_INET6 = Constant('AF_INET6',10)
AF_ROSE = Constant('AF_ROSE',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_NETBEUI = Constant('AF_NETBEUI',13)
AF_SECURITY = Constant('AF_SECURITY',14)
AF_KEY = Constant('AF_KEY',15)
AF_NETLINK = Constant('AF_NETLINK',16)
AF_ROUTE = Constant('AF_ROUTE',16)
AF_PACKET = Constant('AF_PACKET',17)
AF_ASH = Constant('AF_ASH',18)
AF_ECONET = Constant('AF_ECONET',19)
AF_ATMSVC = Constant('AF_ATMSVC',20)
AF_SNA = Constant('AF_SNA',22)
AF_IRDA = Constant('AF_IRDA',23)
AF_PPPOX = Constant('AF_PPPOX',24)
AF_WANPIPE = Constant('AF_WANPIPE',25)
AF_LLC = Constant('AF_LLC',26)
AF_IB = Constant('AF_IB',27)
AF_MPLS = Constant('AF_MPLS',28)
AF_CAN = Constant('AF_CAN',29)
AF_TIPC = Constant('AF_TIPC',30)
AF_BLUETOOTH = Constant('AF_BLUETOOTH',31)
AF_IUCV = Constant('AF_IUCV',32)
AF_RXRPC = Constant('AF_RXRPC',33)
AF_ISDN = Constant('AF_ISDN',34)
AF_PHONET = Constant('AF_PHONET',35)
AF_IEEE802154 = Constant('AF_IEEE802154',36)
AF_CAIF = Constant('AF_CAIF',37)
AF_ALG = Constant('AF_ALG',38)
AF_NFC = Constant('AF_NFC',39)
AF_VSOCK = Constant('AF_VSOCK',40)
AF_KCM = Constant('AF_KCM',41)
AF_QIPCRTR = Constant('AF_QIPCRTR',42)
AF_SMC = Constant('AF_SMC',43)
AF_MAX = Constant('AF_MAX',44)
PF_UNSPEC = Constant('PF_UNSPEC',0)
PF_UNIX = Constant('PF_UNIX',1)
PF_LOCAL = Constant('PF_LOCAL',1)
PF_INET = Constant('PF_INET',2)
PF_AX25 = Constant('PF_AX25',3)
PF_IPX = Constant('PF_IPX',4)
PF_APPLETALK = Constant('PF_APPLETALK',5)
PF_NETROM = Constant('PF_NETROM',6)
PF_BRIDGE = Constant('PF_BRIDGE',7)
PF_ATMPVC = Constant('PF_ATMPVC',8)
PF_X25 = Constant('PF_X25',9)
PF_INET6 = Constant('PF_INET6',10)
PF_ROSE = Constant('PF_ROSE',11)
PF_DECnet = Constant('PF_DECnet',12)
PF_NETBEUI = Constant('PF_NETBEUI',13)
PF_SECURITY = Constant('PF_SECURITY',14)
PF_KEY = Constant('PF_KEY',15)
PF_NETLINK = Constant('PF_NETLINK',16)
PF_ROUTE = Constant('PF_ROUTE',16)
PF_PACKET = Constant('PF_PACKET',17)
PF_ASH = Constant('PF_ASH',18)
PF_ECONET = Constant('PF_ECONET',19)
PF_ATMSVC = Constant('PF_ATMSVC',20)
PF_SNA = Constant('PF_SNA',22)
PF_IRDA = Constant('PF_IRDA',23)
PF_PPPOX = Constant('PF_PPPOX',24)
PF_WANPIPE = Constant('PF_WANPIPE',25)
PF_LLC = Constant('PF_LLC',26)
PF_IB = Constant('PF_IB',27)
PF_MPLS = Constant('PF_MPLS',28)
PF_CAN = Constant('PF_CAN',29)
PF_TIPC = Constant('PF_TIPC',30)
PF_BLUETOOTH = Constant('PF_BLUETOOTH',31)
PF_IUCV = Constant('PF_IUCV',32)
PF_RXRPC = Constant('PF_RXRPC',33)
PF_ISDN = Constant('PF_ISDN',34)
PF_PHONET = Constant('PF_PHONET',35)
PF_IEEE802154 = Constant('PF_IEEE802154',36)
PF_CAIF = Constant('PF_CAIF',37)
PF_ALG = Constant('PF_ALG',38)
PF_NFC = Constant('PF_NFC',39)
PF_VSOCK = Constant('PF_VSOCK',40)
PF_KCM = Constant('PF_KCM',41)
PF_QIPCRTR = Constant('PF_QIPCRTR',42)
PF_SMC = Constant('PF_SMC',43)
PF_MAX = Constant('PF_MAX',44)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',1)
MSG_PEEK = Constant('MSG_PEEK',2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',4)
MSG_TRYHARD = Constant('MSG_TRYHARD',4)
MSG_CTRUNC = Constant('MSG_CTRUNC',8)
MSG_PROBE = Constant('MSG_PROBE',0x10)
MSG_TRUNC = Constant('MSG_TRUNC',0x20)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x40)
MSG_EOR = Constant('MSG_EOR',0x80)
MSG_WAITALL = Constant('MSG_WAITALL',0x100)
MSG_FIN = Constant('MSG_FIN',0x200)
MSG_SYN = Constant('MSG_SYN',0x400)
MSG_CONFIRM = Constant('MSG_CONFIRM',0x800)
MSG_RST = Constant('MSG_RST',0x1000)
MSG_ERRQUEUE = Constant('MSG_ERRQUEUE',0x2000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x4000)
MSG_MORE = Constant('MSG_MORE',0x8000)
MSG_WAITFORONE = Constant('MSG_WAITFORONE',0x10000)
MSG_SENDPAGE_NOTLAST = Constant('MSG_SENDPAGE_NOTLAST',0x20000)
MSG_BATCH = Constant('MSG_BATCH',0x40000)
MSG_EOF = Constant('MSG_EOF',0x200)
MSG_ZEROCOPY = Constant('MSG_ZEROCOPY',0x4000000)
MSG_FASTOPEN = Constant('MSG_FASTOPEN',0x20000000)
MSG_CMSG_CLOEXEC = Constant('MSG_CMSG_CLOEXEC',0x40000000)
SOL_IP = Constant('SOL_IP',0)
SOL_TCP = Constant('SOL_TCP',6)
SOL_UDP = Constant('SOL_UDP',17)
SOL_IPV6 = Constant('SOL_IPV6',41)
SOL_ICMPV6 = Constant('SOL_ICMPV6',58)
SOL_SCTP = Constant('SOL_SCTP',132)
SOL_UDPLITE = Constant('SOL_UDPLITE',136)
SOL_RAW = Constant('SOL_RAW',255)
SOL_IPX = Constant('SOL_IPX',256)
SOL_AX25 = Constant('SOL_AX25',257)
SOL_ATALK = Constant('SOL_ATALK',258)
SOL_NETROM = Constant('SOL_NETROM',259)
SOL_ROSE = Constant('SOL_ROSE',260)
SOL_DECNET = Constant('SOL_DECNET',261)
SOL_X25 = Constant('SOL_X25',262)
SOL_PACKET = Constant('SOL_PACKET',263)
SOL_ATM = Constant('SOL_ATM',264)
SOL_AAL = Constant('SOL_AAL',265)
SOL_IRDA = Constant('SOL_IRDA',266)
SOL_NETBEUI = Constant('SOL_NETBEUI',267)
SOL_LLC = Constant('SOL_LLC',268)
SOL_DCCP = Constant('SOL_DCCP',269)
SOL_NETLINK = Constant('SOL_NETLINK',270)
SOL_TIPC = Constant('SOL_TIPC',271)
SOL_RXRPC = Constant('SOL_RXRPC',272)
SOL_PPPOL2TP = Constant('SOL_PPPOL2TP',273)
SOL_BLUETOOTH = Constant('SOL_BLUETOOTH',274)
SOL_PNPIPE = Constant('SOL_PNPIPE',275)
SOL_RDS = Constant('SOL_RDS',276)
SOL_IUCV = Constant('SOL_IUCV',277)
SOL_CAIF = Constant('SOL_CAIF',278)
SOL_ALG = Constant('SOL_ALG',279)
SOL_NFC = Constant('SOL_NFC',280)
SOL_KCM = Constant('SOL_KCM',281)
SOL_TLS = Constant('SOL_TLS',282)
IPX_TYPE = Constant('IPX_TYPE',1)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
NI_NOFQDN = Constant('NI_NOFQDN',1)
NI_NUMERICHOST = Constant('NI_NUMERICHOST',2)
NI_NAMEREQD = Constant('NI_NAMEREQD',4)
NI_NUMERICSERV = Constant('NI_NUMERICSERV',8)
NI_DGRAM = Constant('NI_DGRAM',16)
EAI_FAMILY = Constant('EAI_FAMILY',-1)
EAI_SOCKTYPE = Constant('EAI_SOCKTYPE',-2)
EAI_BADFLAGS = Constant('EAI_BADFLAGS',-3)
EAI_NONAME = Constant('EAI_NONAME',-4)
EAI_SERVICE = Constant('EAI_SERVICE',-5)
EAI_ADDRFAMILY = Constant('EAI_ADDRFAMILY',-6)
EAI_NODATA = Constant('EAI_NODATA',-7)
EAI_MEMORY = Constant('EAI_MEMORY',-8)
EAI_FAIL = Constant('EAI_FAIL',-9)
EAI_AGAIN = Constant('EAI_AGAIN',-10)
EAI_SYSTEM = Constant('EAI_SYSTEM',-11)
AI_NUMERICHOST = Constant('AI_NUMERICHOST',1)
AI_CANONNAME = Constant('AI_CANONNAME',2)
AI_PASSIVE = Constant('AI_PASSIVE',4)
AI_NUMERICSERV = Constant('AI_NUMERICSERV',8)
AI_ADDRCONFIG = Constant('AI_ADDRCONFIG',16)
AI_V4MAPPED = Constant('AI_V4MAPPED',32)
AI_ALL = Constant('AI_ALL',64)
SIOCADDRT = Constant('SIOCADDRT',0x890B)
SIOCDELRT = Constant('SIOCDELRT',0x890C)
SIOCRTMSG = Constant('SIOCRTMSG',0x890D)
SIOCGIFNAME = Constant('SIOCGIFNAME',0x8910)
SIOCSIFLINK = Constant('SIOCSIFLINK',0x8911)
SIOCGIFCONF = Constant('SIOCGIFCONF',0x8912)
SIOCGIFFLAGS = Constant('SIOCGIFFLAGS',0x8913)
SIOCSIFFLAGS = Constant('SIOCSIFFLAGS',0x8914)
SIOCGIFADDR = Constant('SIOCGIFADDR',0x8915)
SIOCSIFADDR = Constant('SIOCSIFADDR',0x8916)
SIOCGIFDSTADDR = Constant('SIOCGIFDSTADDR',0x8917)
SIOCSIFDSTADDR = Constant('SIOCSIFDSTADDR',0x8918)
SIOCGIFBRDADDR = Constant('SIOCGIFBRDADDR',0x8919)
SIOCSIFBRDADDR = Constant('SIOCSIFBRDADDR',0x891a)
SIOCGIFNETMASK = Constant('SIOCGIFNETMASK',0x891b)
SIOCSIFNETMASK = Constant('SIOCSIFNETMASK',0x891c)
SIOCGIFMETRIC = Constant('SIOCGIFMETRIC',0x891d)
SIOCSIFMETRIC = Constant('SIOCSIFMETRIC',0x891e)
SIOCGIFMEM = Constant('SIOCGIFMEM',0x891f)
SIOCSIFMEM = Constant('SIOCSIFMEM',0x8920)
SIOCGIFMTU = Constant('SIOCGIFMTU',0x8921)
SIOCSIFMTU = Constant('SIOCSIFMTU',0x8922)
SIOCSIFNAME = Constant('SIOCSIFNAME',0x8923)
SIOCSIFHWADDR = Constant('SIOCSIFHWADDR',0x8924)
SIOCGIFENCAP = Constant('SIOCGIFENCAP',0x8925)
SIOCSIFENCAP = Constant('SIOCSIFENCAP',0x8926)
SIOCGIFHWADDR = Constant('SIOCGIFHWADDR',0x8927)
SIOCGIFSLAVE = Constant('SIOCGIFSLAVE',0x8929)
SIOCSIFSLAVE = Constant('SIOCSIFSLAVE',0x8930)
SIOCADDMULTI = Constant('SIOCADDMULTI',0x8931)
SIOCDELMULTI = Constant('SIOCDELMULTI',0x8932)
SIOCGIFINDEX = Constant('SIOCGIFINDEX',0x8933)
SIOGIFINDEX = Constant('SIOGIFINDEX',0x8933)
SIOCSIFPFLAGS = Constant('SIOCSIFPFLAGS',0x8934)
SIOCGIFPFLAGS = Constant('SIOCGIFPFLAGS',0x8935)
SIOCDIFADDR = Constant('SIOCDIFADDR',0x8936)
SIOCSIFHWBROADCAST = Constant('SIOCSIFHWBROADCAST',0x8937)
SIOCGIFCOUNT = Constant('SIOCGIFCOUNT',0x8938)
SIOCGIFBR = Constant('SIOCGIFBR',0x8940)
SIOCSIFBR = Constant('SIOCSIFBR',0x8941)
SIOCGIFTXQLEN = Constant('SIOCGIFTXQLEN',0x8942)
SIOCSIFTXQLEN = Constant('SIOCSIFTXQLEN',0x8943)
SIOCGIFDIVERT = Constant('SIOCGIFDIVERT',0x8944)
SIOCSIFDIVERT = Constant('SIOCSIFDIVERT',0x8945)
SIOCETHTOOL = Constant('SIOCETHTOOL',0x8946)
SIOCDARP = Constant('SIOCDARP',0x8953)
SIOCGARP = Constant('SIOCGARP',0x8954)
SIOCSARP = Constant('SIOCSARP',0x8955)
SIOCDRARP = Constant('SIOCDRARP',0x8960)
SIOCGRARP = Constant('SIOCGRARP',0x8961)
SIOCSRARP = Constant('SIOCSRARP',0x8962)
SIOCGIFMAP = Constant('SIOCGIFMAP',0x8970)
SIOCSIFMAP = Constant('SIOCSIFMAP',0x8971)
SIOCADDDLCI = Constant('SIOCADDDLCI',0x8980)
SIOCDELDLCI = Constant('SIOCDELDLCI',0x8981)
SIOCDEVPRIVATE = Constant('SIOCDEVPRIVATE',0x89F0)
F_LINUX_SPECIFIC_BASE = Constant('F_LINUX_SPECIFIC_BASE',1024)
O_ACCMODE = Constant('O_ACCMODE',0o003)
O_RDONLY = Constant('O_RDONLY',0o0)
O_WRONLY = Constant('O_WRONLY',0o1)
O_RDWR = Constant('O_RDWR',0o2)
O_CREAT = Constant('O_CREAT',0o100)
O_EXCL = Constant('O_EXCL',0o200)
O_NOCTTY = Constant('O_NOCTTY',0o400)
O_TRUNC = Constant('O_TRUNC',0o1000)
O_APPEND = Constant('O_APPEND',0o2000)
O_NONBLOCK = Constant('O_NONBLOCK',0o4000)
O_NDELAY = Constant('O_NDELAY',0o4000)
O_DSYNC = Constant('O_DSYNC',0o10000)
FASYNC = Constant('FASYNC',0o20000)
O_DIRECT = Constant('O_DIRECT',0o40000)
O_LARGEFILE = Constant('O_LARGEFILE',0o100000)
O_DIRECTORY = Constant('O_DIRECTORY',0o200000)
O_NOFOLLOW = Constant('O_NOFOLLOW',0o400000)
O_NOATIME = Constant('O_NOATIME',0o1000000)
O_CLOEXEC = Constant('O_CLOEXEC',0o2000000)
O_SYNC = Constant('O_SYNC',(0o10000|0o4000000))
O_PATH = Constant('O_PATH',0o10000000)
__O_TMPFILE = Constant('__O_TMPFILE',0o20000000)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETLK = Constant('F_GETLK',5)
F_SETLK = Constant('F_SETLK',6)
F_SETLKW = Constant('F_SETLKW',7)
F_SETOWN = Constant('F_SETOWN',8)
F_GETOWN = Constant('F_GETOWN',9)
F_SETSIG = Constant('F_SETSIG',10)
F_GETSIG = Constant('F_GETSIG',11)
F_GETLK64 = Constant('F_GETLK64',12)
F_SETLK64 = Constant('F_SETLK64',13)
F_SETLKW64 = Constant('F_SETLKW64',14)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',0)
F_WRLCK = Constant('F_WRLCK',1)
F_UNLCK = Constant('F_UNLCK',2)
F_EXLCK = Constant('F_EXLCK',4)
F_SHLCK = Constant('F_SHLCK',8)
F_INPROGRESS = Constant('F_INPROGRESS',16)
LOCK_SH = Constant('LOCK_SH',1)
LOCK_EX = Constant('LOCK_EX',2)
LOCK_NB = Constant('LOCK_NB',4)
LOCK_UN = Constant('LOCK_UN',8)
LOCK_MAND = Constant('LOCK_MAND',32)
LOCK_READ = Constant('LOCK_READ',64)
LOCK_WRITE = Constant('LOCK_WRITE',128)
LOCK_RW = Constant('LOCK_RW',192)
O_TMPFILE = Constant('O_TMPFILE',(0o20000000 | 0o200000))
O_ASYNC = Constant('O_ASYNC',0o20000)
F_SETOWN_EX = Constant('F_SETOWN_EX',15)
F_GETOWN_EX = Constant('F_GETOWN_EX',16)
F_GETOWNER_UIDS = Constant('F_GETOWNER_UIDS',17)
F_OFD_GETLK = Constant('F_OFD_GETLK',36)
F_OFD_SETLK = Constant('F_OFD_SETLK',37)
F_OFD_SETLKW = Constant('F_OFD_SETLKW',38)
F_OWNER_TID = Constant('F_OWNER_TID',0)
F_OWNER_PID = Constant('F_OWNER_PID',1)
F_OWNER_PGRP = Constant('F_OWNER_PGRP',2)
AT_FDCWD = Constant('AT_FDCWD',-100)
AT_SYMLINK_NOFOLLOW = Constant('AT_SYMLINK_NOFOLLOW',0x100)
AT_REMOVEDIR = Constant('AT_REMOVEDIR',0x200)
AT_SYMLINK_FOLLOW = Constant('AT_SYMLINK_FOLLOW',0x400)
AT_NO_AUTOMOUNT = Constant('AT_NO_AUTOMOUNT',0x800)
AT_EMPTY_PATH = Constant('AT_EMPTY_PATH',0x1000)
AT_EACCESS = Constant('AT_EACCESS',0x200)
MREMAP_MAYMOVE = Constant('MREMAP_MAYMOVE',1)
MREMAP_FIXED = Constant('MREMAP_FIXED',2)
PROT_READ = Constant('PROT_READ',0x1)
PROT_WRITE = Constant('PROT_WRITE',0x2)
PROT_EXEC = Constant('PROT_EXEC',0x4)
PROT_SEM = Constant('PROT_SEM',0x8)
PROT_NONE = Constant('PROT_NONE',0x0)
PROT_GROWSDOWN = Constant('PROT_GROWSDOWN',0x01000000)
PROT_GROWSUP = Constant('PROT_GROWSUP',0x02000000)
MAP_SHARED = Constant('MAP_SHARED',0x01)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x02)
MAP_TYPE = Constant('MAP_TYPE',0xf)
MADV_REMOVE = Constant('MADV_REMOVE',9)
MADV_DONTFORK = Constant('MADV_DONTFORK',10)
MADV_DOFORK = Constant('MADV_DOFORK',11)
MADV_MERGEABLE = Constant('MADV_MERGEABLE',12)
MADV_UNMERGEABLE = Constant('MADV_UNMERGEABLE',13)
MADV_HUGEPAGE = Constant('MADV_HUGEPAGE',14)
MADV_NOHUGEPAGE = Constant('MADV_NOHUGEPAGE',15)
MADV_DONTDUMP = Constant('MADV_DONTDUMP',16)
MADV_DODUMP = Constant('MADV_DODUMP',17)
MADV_HWPOISON = Constant('MADV_HWPOISON',100)
MADV_SOFT_OFFLINE = Constant('MADV_SOFT_OFFLINE',101)
MLOCK_ONFAULT = Constant('MLOCK_ONFAULT',1)
MAP_FIXED = Constant('MAP_FIXED',0x10)
MAP_ANONYMOUS = Constant('MAP_ANONYMOUS',0x20)
MAP_GROWSDOWN = Constant('MAP_GROWSDOWN',0x0100)
MAP_DENYWRITE = Constant('MAP_DENYWRITE',0x0800)
MAP_EXECUTABLE = Constant('MAP_EXECUTABLE',0x1000)
MAP_LOCKED = Constant('MAP_LOCKED',0x2000)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x4000)
MAP_POPULATE = Constant('MAP_POPULATE',0x8000)
MAP_NONBLOCK = Constant('MAP_NONBLOCK',0x10000)
MAP_STACK = Constant('MAP_STACK',0x20000)
MAP_HUGETLB = Constant('MAP_HUGETLB',0x40000)
MS_ASYNC = Constant('MS_ASYNC',1)
MS_INVALIDATE = Constant('MS_INVALIDATE',2)
MS_SYNC = Constant('MS_SYNC',4)
MCL_CURRENT = Constant('MCL_CURRENT',1)
MCL_FUTURE = Constant('MCL_FUTURE',2)
MCL_ONFAULT = Constant('MCL_ONFAULT',4)
MADV_NORMAL = Constant('MADV_NORMAL',0x0)
MADV_RANDOM = Constant('MADV_RANDOM',0x1)
MADV_SEQUENTIAL = Constant('MADV_SEQUENTIAL',0x2)
MADV_WILLNEED = Constant('MADV_WILLNEED',0x3)
MADV_DONTNEED = Constant('MADV_DONTNEED',0x4)
MAP_ANON = Constant('MAP_ANON',0x20)
MAP_FILE = Constant('MAP_FILE',0)
POSIX_MADV_NORMAL = Constant('POSIX_MADV_NORMAL',0x0)
POSIX_MADV_SEQUENTIAL = Constant('POSIX_MADV_SEQUENTIAL',0x2)
POSIX_MADV_RANDOM = Constant('POSIX_MADV_RANDOM',0x1)
POSIX_MADV_WILLNEED = Constant('POSIX_MADV_WILLNEED',0x3)
POSIX_MADV_DONTNEED = Constant('POSIX_MADV_DONTNEED',0x4)
PTRACE_TRACEME = Constant('PTRACE_TRACEME',0)
PTRACE_PEEKTEXT = Constant('PTRACE_PEEKTEXT',1)
PTRACE_PEEKDATA = Constant('PTRACE_PEEKDATA',2)
PTRACE_PEEKUSR = Constant('PTRACE_PEEKUSR',3)
PTRACE_PEEKUSER = Constant('PTRACE_PEEKUSER',3)
PTRACE_POKETEXT = Constant('PTRACE_POKETEXT',4)
PTRACE_POKEDATA = Constant('PTRACE_POKEDATA',5)
PTRACE_POKEUSR = Constant('PTRACE_POKEUSR',6)
PTRACE_POKEUSER = Constant('PTRACE_POKEUSER',6)
PTRACE_CONT = Constant('PTRACE_CONT',7)
PTRACE_KILL = Constant('PTRACE_KILL',8)
PTRACE_SINGLESTEP = Constant('PTRACE_SINGLESTEP',9)
PTRACE_ATTACH = Constant('PTRACE_ATTACH',0x10)
PTRACE_DETACH = Constant('PTRACE_DETACH',0x11)
PTRACE_SYSCALL = Constant('PTRACE_SYSCALL',24)
PTRACE_GETEVENTMSG = Constant('PTRACE_GETEVENTMSG',0x4201)
PTRACE_GETSIGINFO = Constant('PTRACE_GETSIGINFO',0x4202)
PTRACE_SETSIGINFO = Constant('PTRACE_SETSIGINFO',0x4203)
PTRACE_O_TRACESYSGOOD = Constant('PTRACE_O_TRACESYSGOOD',0x00000001)
PTRACE_O_TRACEFORK = Constant('PTRACE_O_TRACEFORK',0x00000002)
PTRACE_O_TRACEVFORK = Constant('PTRACE_O_TRACEVFORK',0x00000004)
PTRACE_O_TRACECLONE = Constant('PTRACE_O_TRACECLONE',0x00000008)
PTRACE_O_TRACEEXEC = Constant('PTRACE_O_TRACEEXEC',0x00000010)
PTRACE_O_TRACEVFORKDONE = Constant('PTRACE_O_TRACEVFORKDONE',0x00000020)
PTRACE_O_TRACEEXIT = Constant('PTRACE_O_TRACEEXIT',0x00000040)
PTRACE_O_MASK = Constant('PTRACE_O_MASK',0x0000007f)
PTRACE_EVENT_FORK = Constant('PTRACE_EVENT_FORK',1)
PTRACE_EVENT_VFORK = Constant('PTRACE_EVENT_VFORK',2)
PTRACE_EVENT_CLONE = Constant('PTRACE_EVENT_CLONE',3)
PTRACE_EVENT_EXEC = Constant('PTRACE_EVENT_EXEC',4)
PTRACE_EVENT_VFORK_DONE = Constant('PTRACE_EVENT_VFORK_DONE',5)
PTRACE_EVENT_EXIT = Constant('PTRACE_EVENT_EXIT',6)
PT_TRACE_ME = Constant('PT_TRACE_ME',0)
PT_READ_I = Constant('PT_READ_I',1)
PT_READ_D = Constant('PT_READ_D',2)
PT_READ_U = Constant('PT_READ_U',3)
PT_WRITE_I = Constant('PT_WRITE_I',4)
PT_WRITE_D = Constant('PT_WRITE_D',5)
PT_WRITE_U = Constant('PT_WRITE_U',6)
PT_CONTINUE = Constant('PT_CONTINUE',7)
PT_KILL = Constant('PT_KILL',8)
PT_STEP = Constant('PT_STEP',9)
PT_ATTACH = Constant('PT_ATTACH',0x10)
PT_DETACH = Constant('PT_DETACH',0x11)
EBX = Constant('EBX',0)
ECX = Constant('ECX',1)
EDX = Constant('EDX',2)
ESI = Constant('ESI',3)
EDI = Constant('EDI',4)
EBP = Constant('EBP',5)
EAX = Constant('EAX',6)
DS = Constant('DS',7)
ES = Constant('ES',8)
FS = Constant('FS',9)
GS = Constant('GS',10)
ORIG_EAX = Constant('ORIG_EAX',11)
EIP = Constant('EIP',12)
CS = Constant('CS',13)
EFL = Constant('EFL',14)
UESP = Constant('UESP',15)
SS = Constant('SS',16)
FRAME_SIZE = Constant('FRAME_SIZE',17)
PTRACE_GETREGS = Constant('PTRACE_GETREGS',12)
PTRACE_SETREGS = Constant('PTRACE_SETREGS',13)
PTRACE_GETFPREGS = Constant('PTRACE_GETFPREGS',14)
PTRACE_SETFPREGS = Constant('PTRACE_SETFPREGS',15)
PTRACE_GETFPXREGS = Constant('PTRACE_GETFPXREGS',18)
PTRACE_SETFPXREGS = Constant('PTRACE_SETFPXREGS',19)
PTRACE_SETOPTIONS = Constant('PTRACE_SETOPTIONS',21)
PTRACE_O_TRACESYSGOOD = Constant('PTRACE_O_TRACESYSGOOD',0x00000001)
SYS_accept4 = Constant('SYS_accept4',364)
SYS_access = Constant('SYS_access',33)
SYS_acct = Constant('SYS_acct',51)
SYS_add_key = Constant('SYS_add_key',286)
SYS_adjtimex = Constant('SYS_adjtimex',124)
SYS_afs_syscall = Constant('SYS_afs_syscall',137)
SYS_alarm = Constant('SYS_alarm',27)
SYS_bdflush = Constant('SYS_bdflush',134)
SYS_bind = Constant('SYS_bind',361)
SYS_bpf = Constant('SYS_bpf',357)
SYS_break = Constant('SYS_break',17)
SYS_brk = Constant('SYS_brk',45)
SYS_capget = Constant('SYS_capget',184)
SYS_capset = Constant('SYS_capset',185)
SYS_chdir = Constant('SYS_chdir',12)
SYS_chmod = Constant('SYS_chmod',15)
SYS_chown = Constant('SYS_chown',182)
SYS_chown32 = Constant('SYS_chown32',212)
SYS_chroot = Constant('SYS_chroot',61)
SYS_clock_adjtime = Constant('SYS_clock_adjtime',343)
SYS_clock_adjtime64 = Constant('SYS_clock_adjtime64',405)
SYS_clock_getres = Constant('SYS_clock_getres',(259+7))
SYS_clock_getres_time64 = Constant('SYS_clock_getres_time64',406)
SYS_clock_gettime = Constant('SYS_clock_gettime',(259+6))
SYS_clock_gettime64 = Constant('SYS_clock_gettime64',403)
SYS_clock_nanosleep = Constant('SYS_clock_nanosleep',(259+8))
SYS_clock_nanosleep_time64 = Constant('SYS_clock_nanosleep_time64',407)
SYS_clock_settime = Constant('SYS_clock_settime',(259+5))
SYS_clock_settime64 = Constant('SYS_clock_settime64',404)
SYS_clone = Constant('SYS_clone',120)
SYS_clone3 = Constant('SYS_clone3',435)
SYS_close = Constant('SYS_close',6)
SYS_connect = Constant('SYS_connect',362)
SYS_copy_file_range = Constant('SYS_copy_file_range',377)
SYS_creat = Constant('SYS_creat',8)
SYS_create_module = Constant('SYS_create_module',127)
SYS_delete_module = Constant('SYS_delete_module',129)
SYS_dup = Constant('SYS_dup',41)
SYS_dup2 = Constant('SYS_dup2',63)
SYS_dup3 = Constant('SYS_dup3',330)
SYS_epoll_create = Constant('SYS_epoll_create',254)
SYS_epoll_create1 = Constant('SYS_epoll_create1',329)
SYS_epoll_ctl = Constant('SYS_epoll_ctl',255)
SYS_epoll_pwait = Constant('SYS_epoll_pwait',319)
SYS_epoll_wait = Constant('SYS_epoll_wait',256)
SYS_eventfd = Constant('SYS_eventfd',323)
SYS_eventfd2 = Constant('SYS_eventfd2',328)
SYS_execve = Constant('SYS_execve',11)
SYS_execveat = Constant('SYS_execveat',358)
SYS_exit = Constant('SYS_exit',1)
SYS_exit_group = Constant('SYS_exit_group',252)
SYS_faccessat = Constant('SYS_faccessat',307)
SYS_fadvise64 = Constant('SYS_fadvise64',250)
SYS_fadvise64_64 = Constant('SYS_fadvise64_64',272)
SYS_fallocate = Constant('SYS_fallocate',324)
SYS_fanotify_init = Constant('SYS_fanotify_init',338)
SYS_fanotify_mark = Constant('SYS_fanotify_mark',339)
SYS_fchdir = Constant('SYS_fchdir',133)
SYS_fchmod = Constant('SYS_fchmod',94)
SYS_fchmodat = Constant('SYS_fchmodat',306)
SYS_fchown = Constant('SYS_fchown',95)
SYS_fchown32 = Constant('SYS_fchown32',207)
SYS_fchownat = Constant('SYS_fchownat',298)
SYS_fcntl = Constant('SYS_fcntl',55)
SYS_fcntl64 = Constant('SYS_fcntl64',221)
SYS_fdatasync = Constant('SYS_fdatasync',148)
SYS_fgetxattr = Constant('SYS_fgetxattr',231)
SYS_finit_module = Constant('SYS_finit_module',350)
SYS_flistxattr = Constant('SYS_flistxattr',234)
SYS_flock = Constant('SYS_flock',143)
SYS_fork = Constant('SYS_fork',2)
SYS_fremovexattr = Constant('SYS_fremovexattr',237)
SYS_fsconfig = Constant('SYS_fsconfig',431)
SYS_fsetxattr = Constant('SYS_fsetxattr',228)
SYS_fsmount = Constant('SYS_fsmount',432)
SYS_fsopen = Constant('SYS_fsopen',430)
SYS_fspick = Constant('SYS_fspick',433)
SYS_fstat = Constant('SYS_fstat',108)
SYS_fstat64 = Constant('SYS_fstat64',197)
SYS_fstatat64 = Constant('SYS_fstatat64',300)
SYS_fstatfs = Constant('SYS_fstatfs',100)
SYS_fstatfs64 = Constant('SYS_fstatfs64',269)
SYS_fsync = Constant('SYS_fsync',118)
SYS_ftime = Constant('SYS_ftime',35)
SYS_ftruncate = Constant('SYS_ftruncate',93)
SYS_ftruncate64 = Constant('SYS_ftruncate64',194)
SYS_futex = Constant('SYS_futex',240)
SYS_futex_time64 = Constant('SYS_futex_time64',422)
SYS_futimesat = Constant('SYS_futimesat',299)
SYS_getcpu = Constant('SYS_getcpu',318)
SYS_getcwd = Constant('SYS_getcwd',183)
SYS_getdents = Constant('SYS_getdents',141)
SYS_getdents64 = Constant('SYS_getdents64',220)
SYS_getegid = Constant('SYS_getegid',50)
SYS_getegid32 = Constant('SYS_getegid32',202)
SYS_geteuid = Constant('SYS_geteuid',49)
SYS_geteuid32 = Constant('SYS_geteuid32',201)
SYS_getgid = Constant('SYS_getgid',47)
SYS_getgid32 = Constant('SYS_getgid32',200)
SYS_getgroups = Constant('SYS_getgroups',80)
SYS_getgroups32 = Constant('SYS_getgroups32',205)
SYS_getitimer = Constant('SYS_getitimer',105)
SYS_get_kernel_syms = Constant('SYS_get_kernel_syms',130)
SYS_get_mempolicy = Constant('SYS_get_mempolicy',275)
SYS_getpeername = Constant('SYS_getpeername',368)
SYS_getpgid = Constant('SYS_getpgid',132)
SYS_getpgrp = Constant('SYS_getpgrp',65)
SYS_getpid = Constant('SYS_getpid',20)
SYS_getpmsg = Constant('SYS_getpmsg',188)
SYS_getppid = Constant('SYS_getppid',64)
SYS_getpriority = Constant('SYS_getpriority',96)
SYS_getrandom = Constant('SYS_getrandom',355)
SYS_getresgid = Constant('SYS_getresgid',171)
SYS_getresgid32 = Constant('SYS_getresgid32',211)
SYS_getresuid = Constant('SYS_getresuid',165)
SYS_getresuid32 = Constant('SYS_getresuid32',209)
SYS_getrlimit = Constant('SYS_getrlimit',76)
SYS_get_robust_list = Constant('SYS_get_robust_list',312)
SYS_getrusage = Constant('SYS_getrusage',77)
SYS_getsid = Constant('SYS_getsid',147)
SYS_getsockname = Constant('SYS_getsockname',367)
SYS_getsockopt = Constant('SYS_getsockopt',365)
SYS_get_thread_area = Constant('SYS_get_thread_area',244)
SYS_gettid = Constant('SYS_gettid',224)
SYS_gettimeofday = Constant('SYS_gettimeofday',78)
SYS_getuid = Constant('SYS_getuid',24)
SYS_getuid32 = Constant('SYS_getuid32',199)
SYS_getxattr = Constant('SYS_getxattr',229)
SYS_gtty = Constant('SYS_gtty',32)
SYS_ia32_arch_prctl = Constant('SYS_ia32_arch_prctl',384)
SYS_ia32_io_pgetevents = Constant('SYS_ia32_io_pgetevents',385)
SYS_ia32_rseq = Constant('SYS_ia32_rseq',386)
SYS_ia32_statx = Constant('SYS_ia32_statx',383)
SYS_idle = Constant('SYS_idle',112)
SYS_init_module = Constant('SYS_init_module',128)
SYS_inotify_add_watch = Constant('SYS_inotify_add_watch',292)
SYS_inotify_init = Constant('SYS_inotify_init',291)
SYS_inotify_init1 = Constant('SYS_inotify_init1',332)
SYS_inotify_rm_watch = Constant('SYS_inotify_rm_watch',293)
SYS_io_cancel = Constant('SYS_io_cancel',249)
SYS_ioctl = Constant('SYS_ioctl',54)
SYS_io_destroy = Constant('SYS_io_destroy',246)
SYS_io_getevents = Constant('SYS_io_getevents',247)
SYS_ioperm = Constant('SYS_ioperm',101)
SYS_io_pgetevents_time64 = Constant('SYS_io_pgetevents_time64',416)
SYS_iopl = Constant('SYS_iopl',110)
SYS_ioprio_get = Constant('SYS_ioprio_get',290)
SYS_ioprio_set = Constant('SYS_ioprio_set',289)
SYS_io_setup = Constant('SYS_io_setup',245)
SYS_io_submit = Constant('SYS_io_submit',248)
SYS_io_uring_enter = Constant('SYS_io_uring_enter',426)
SYS_io_uring_register = Constant('SYS_io_uring_register',427)
SYS_io_uring_setup = Constant('SYS_io_uring_setup',425)
SYS_ipc = Constant('SYS_ipc',117)
SYS_kcmp = Constant('SYS_kcmp',349)
SYS_keyctl = Constant('SYS_keyctl',288)
SYS_kill = Constant('SYS_kill',37)
SYS_lchown = Constant('SYS_lchown',16)
SYS_lchown32 = Constant('SYS_lchown32',198)
SYS_lgetxattr = Constant('SYS_lgetxattr',230)
SYS_link = Constant('SYS_link',9)
SYS_linkat = Constant('SYS_linkat',303)
SYS_listen = Constant('SYS_listen',363)
SYS_listxattr = Constant('SYS_listxattr',232)
SYS_llistxattr = Constant('SYS_llistxattr',233)
SYS__llseek = Constant('SYS__llseek',140)
SYS_lock = Constant('SYS_lock',53)
SYS_lookup_dcookie = Constant('SYS_lookup_dcookie',253)
SYS_lremovexattr = Constant('SYS_lremovexattr',236)
SYS_lseek = Constant('SYS_lseek',19)
SYS_lsetxattr = Constant('SYS_lsetxattr',227)
SYS_lstat = Constant('SYS_lstat',107)
SYS_lstat64 = Constant('SYS_lstat64',196)
SYS_madvise = Constant('SYS_madvise',219)
SYS_madvise1 = Constant('SYS_madvise1',219)
SYS_mbind = Constant('SYS_mbind',274)
SYS_membarrier = Constant('SYS_membarrier',375)
SYS_memfd_create = Constant('SYS_memfd_create',356)
SYS_migrate_pages = Constant('SYS_migrate_pages',294)
SYS_mincore = Constant('SYS_mincore',218)
SYS_mkdir = Constant('SYS_mkdir',39)
SYS_mkdirat = Constant('SYS_mkdirat',296)
SYS_mknod = Constant('SYS_mknod',14)
SYS_mknodat = Constant('SYS_mknodat',297)
SYS_mlock = Constant('SYS_mlock',150)
SYS_mlock2 = Constant('SYS_mlock2',376)
SYS_mlockall = Constant('SYS_mlockall',152)
SYS_mmap = Constant('SYS_mmap',90)
SYS_mmap2 = Constant('SYS_mmap2',192)
SYS_modify_ldt = Constant('SYS_modify_ldt',123)
SYS_mount = Constant('SYS_mount',21)
SYS_move_mount = Constant('SYS_move_mount',429)
SYS_move_pages = Constant('SYS_move_pages',317)
SYS_mprotect = Constant('SYS_mprotect',125)
SYS_mpx = Constant('SYS_mpx',56)
SYS_mq_getsetattr = Constant('SYS_mq_getsetattr',(277+5))
SYS_mq_notify = Constant('SYS_mq_notify',(277+4))
SYS_mq_open = Constant('SYS_mq_open',277)
SYS_mq_timedreceive = Constant('SYS_mq_timedreceive',(277+3))
SYS_mq_timedreceive_time64 = Constant('SYS_mq_timedreceive_time64',419)
SYS_mq_timedsend = Constant('SYS_mq_timedsend',(277+2))
SYS_mq_timedsend_time64 = Constant('SYS_mq_timedsend_time64',418)
SYS_mq_unlink = Constant('SYS_mq_unlink',(277+1))
SYS_mremap = Constant('SYS_mremap',163)
SYS_msgctl = Constant('SYS_msgctl',402)
SYS_msgget = Constant('SYS_msgget',399)
SYS_msgrcv = Constant('SYS_msgrcv',401)
SYS_msgsnd = Constant('SYS_msgsnd',400)
SYS_msync = Constant('SYS_msync',144)
SYS_munlock = Constant('SYS_munlock',151)
SYS_munlockall = Constant('SYS_munlockall',153)
SYS_munmap = Constant('SYS_munmap',91)
SYS_name_to_handle_at = Constant('SYS_name_to_handle_at',341)
SYS_nanosleep = Constant('SYS_nanosleep',162)
SYS__newselect = Constant('SYS__newselect',142)
SYS_nfsservctl = Constant('SYS_nfsservctl',169)
SYS_nice = Constant('SYS_nice',34)
SYS_oldfstat = Constant('SYS_oldfstat',28)
SYS_oldlstat = Constant('SYS_oldlstat',84)
SYS_oldolduname = Constant('SYS_oldolduname',59)
SYS_oldstat = Constant('SYS_oldstat',18)
SYS_olduname = Constant('SYS_olduname',109)
SYS_open = Constant('SYS_open',5)
SYS_openat = Constant('SYS_openat',295)
SYS_openat2 = Constant('SYS_openat2',437)
SYS_open_by_handle_at = Constant('SYS_open_by_handle_at',342)
SYS_open_tree = Constant('SYS_open_tree',428)
SYS_pause = Constant('SYS_pause',29)
SYS_perf_event_open = Constant('SYS_perf_event_open',336)
SYS_personality = Constant('SYS_personality',136)
SYS_pidfd_getfd = Constant('SYS_pidfd_getfd',438)
SYS_pidfd_open = Constant('SYS_pidfd_open',434)
SYS_pidfd_send_signal = Constant('SYS_pidfd_send_signal',424)
SYS_pipe = Constant('SYS_pipe',42)
SYS_pipe2 = Constant('SYS_pipe2',331)
SYS_pivot_root = Constant('SYS_pivot_root',217)
SYS_pkey_alloc = Constant('SYS_pkey_alloc',381)
SYS_pkey_free = Constant('SYS_pkey_free',382)
SYS_pkey_mprotect = Constant('SYS_pkey_mprotect',380)
SYS_poll = Constant('SYS_poll',168)
SYS_ppoll = Constant('SYS_ppoll',309)
SYS_ppoll_time64 = Constant('SYS_ppoll_time64',414)
SYS_prctl = Constant('SYS_prctl',172)
SYS_pread = Constant('SYS_pread',180)
SYS_preadv = Constant('SYS_preadv',333)
SYS_preadv2 = Constant('SYS_preadv2',378)
SYS_prlimit64 = Constant('SYS_prlimit64',340)
SYS_process_vm_readv = Constant('SYS_process_vm_readv',347)
SYS_process_vm_writev = Constant('SYS_process_vm_writev',348)
SYS_prof = Constant('SYS_prof',44)
SYS_profil = Constant('SYS_profil',98)
SYS_pselect6 = Constant('SYS_pselect6',308)
SYS_pselect6_time64 = Constant('SYS_pselect6_time64',413)
SYS_ptrace = Constant('SYS_ptrace',26)
SYS_putpmsg = Constant('SYS_putpmsg',189)
SYS_pwrite = Constant('SYS_pwrite',181)
SYS_pwritev = Constant('SYS_pwritev',334)
SYS_pwritev2 = Constant('SYS_pwritev2',379)
SYS_query_module = Constant('SYS_query_module',167)
SYS_quotactl = Constant('SYS_quotactl',131)
SYS_read = Constant('SYS_read',3)
SYS_readahead = Constant('SYS_readahead',225)
SYS_readdir = Constant('SYS_readdir',89)
SYS_readlink = Constant('SYS_readlink',85)
SYS_readlinkat = Constant('SYS_readlinkat',305)
SYS_readv = Constant('SYS_readv',145)
SYS_reboot = Constant('SYS_reboot',88)
SYS_recvfrom = Constant('SYS_recvfrom',371)
SYS_recvmmsg = Constant('SYS_recvmmsg',337)
SYS_recvmmsg_time64 = Constant('SYS_recvmmsg_time64',417)
SYS_recvmsg = Constant('SYS_recvmsg',372)
SYS_remap_file_pages = Constant('SYS_remap_file_pages',257)
SYS_removexattr = Constant('SYS_removexattr',235)
SYS_rename = Constant('SYS_rename',38)
SYS_renameat = Constant('SYS_renameat',302)
SYS_renameat2 = Constant('SYS_renameat2',353)
SYS_request_key = Constant('SYS_request_key',287)
SYS_rmdir = Constant('SYS_rmdir',40)
SYS_rt_sigaction = Constant('SYS_rt_sigaction',174)
SYS_rt_sigpending = Constant('SYS_rt_sigpending',176)
SYS_rt_sigprocmask = Constant('SYS_rt_sigprocmask',175)
SYS_rt_sigqueueinfo = Constant('SYS_rt_sigqueueinfo',178)
SYS_rt_sigreturn = Constant('SYS_rt_sigreturn',173)
SYS_rt_sigsuspend = Constant('SYS_rt_sigsuspend',179)
SYS_rt_sigtimedwait = Constant('SYS_rt_sigtimedwait',177)
SYS_rt_sigtimedwait_time64 = Constant('SYS_rt_sigtimedwait_time64',421)
SYS_rt_tgsigqueueinfo = Constant('SYS_rt_tgsigqueueinfo',335)
SYS_sched_getaffinity = Constant('SYS_sched_getaffinity',242)
SYS_sched_getattr = Constant('SYS_sched_getattr',352)
SYS_sched_getparam = Constant('SYS_sched_getparam',155)
SYS_sched_get_priority_max = Constant('SYS_sched_get_priority_max',159)
SYS_sched_get_priority_min = Constant('SYS_sched_get_priority_min',160)
SYS_sched_getscheduler = Constant('SYS_sched_getscheduler',157)
SYS_sched_rr_get_interval = Constant('SYS_sched_rr_get_interval',161)
SYS_sched_rr_get_interval_time64 = Constant('SYS_sched_rr_get_interval_time64',423)
SYS_sched_setaffinity = Constant('SYS_sched_setaffinity',241)
SYS_sched_setattr = Constant('SYS_sched_setattr',351)
SYS_sched_setparam = Constant('SYS_sched_setparam',154)
SYS_sched_setscheduler = Constant('SYS_sched_setscheduler',156)
SYS_sched_yield = Constant('SYS_sched_yield',158)
SYS_seccomp = Constant('SYS_seccomp',354)
SYS_select = Constant('SYS_select',82)
SYS_semctl = Constant('SYS_semctl',394)
SYS_semget = Constant('SYS_semget',393)
SYS_semtimedop_time64 = Constant('SYS_semtimedop_time64',420)
SYS_sendfile = Constant('SYS_sendfile',187)
SYS_sendfile64 = Constant('SYS_sendfile64',239)
SYS_sendmmsg = Constant('SYS_sendmmsg',345)
SYS_sendmsg = Constant('SYS_sendmsg',370)
SYS_sendto = Constant('SYS_sendto',369)
SYS_setdomainname = Constant('SYS_setdomainname',121)
SYS_setfsgid = Constant('SYS_setfsgid',139)
SYS_setfsgid32 = Constant('SYS_setfsgid32',216)
SYS_setfsuid = Constant('SYS_setfsuid',138)
SYS_setfsuid32 = Constant('SYS_setfsuid32',215)
SYS_setgid = Constant('SYS_setgid',46)
SYS_setgid32 = Constant('SYS_setgid32',214)
SYS_setgroups = Constant('SYS_setgroups',81)
SYS_setgroups32 = Constant('SYS_setgroups32',206)
SYS_sethostname = Constant('SYS_sethostname',74)
SYS_setitimer = Constant('SYS_setitimer',104)
SYS_set_mempolicy = Constant('SYS_set_mempolicy',276)
SYS_setns = Constant('SYS_setns',346)
SYS_setpgid = Constant('SYS_setpgid',57)
SYS_setpriority = Constant('SYS_setpriority',97)
SYS_setregid = Constant('SYS_setregid',71)
SYS_setregid32 = Constant('SYS_setregid32',204)
SYS_setresgid = Constant('SYS_setresgid',170)
SYS_setresgid32 = Constant('SYS_setresgid32',210)
SYS_setresuid = Constant('SYS_setresuid',164)
SYS_setresuid32 = Constant('SYS_setresuid32',208)
SYS_setreuid = Constant('SYS_setreuid',70)
SYS_setreuid32 = Constant('SYS_setreuid32',203)
SYS_setrlimit = Constant('SYS_setrlimit',75)
SYS_set_robust_list = Constant('SYS_set_robust_list',311)
SYS_setsid = Constant('SYS_setsid',66)
SYS_setsockopt = Constant('SYS_setsockopt',366)
SYS_set_thread_area = Constant('SYS_set_thread_area',243)
SYS_set_tid_address = Constant('SYS_set_tid_address',258)
SYS_settimeofday = Constant('SYS_settimeofday',79)
SYS_setuid = Constant('SYS_setuid',23)
SYS_setuid32 = Constant('SYS_setuid32',213)
SYS_setxattr = Constant('SYS_setxattr',226)
SYS_sgetmask = Constant('SYS_sgetmask',68)
SYS_shmat = Constant('SYS_shmat',397)
SYS_shmctl = Constant('SYS_shmctl',396)
SYS_shmdt = Constant('SYS_shmdt',398)
SYS_shmget = Constant('SYS_shmget',395)
SYS_shutdown = Constant('SYS_shutdown',373)
SYS_sigaction = Constant('SYS_sigaction',67)
SYS_sigaltstack = Constant('SYS_sigaltstack',186)
SYS_signal = Constant('SYS_signal',48)
SYS_signalfd = Constant('SYS_signalfd',321)
SYS_signalfd4 = Constant('SYS_signalfd4',327)
SYS_sigpending = Constant('SYS_sigpending',73)
SYS_sigprocmask = Constant('SYS_sigprocmask',126)
SYS_sigreturn = Constant('SYS_sigreturn',119)
SYS_sigsuspend = Constant('SYS_sigsuspend',72)
SYS_socket = Constant('SYS_socket',359)
SYS_socketcall = Constant('SYS_socketcall',102)
SYS_socketpair = Constant('SYS_socketpair',360)
SYS_splice = Constant('SYS_splice',313)
SYS_ssetmask = Constant('SYS_ssetmask',69)
SYS_stat = Constant('SYS_stat',106)
SYS_stat64 = Constant('SYS_stat64',195)
SYS_statfs = Constant('SYS_statfs',99)
SYS_statfs64 = Constant('SYS_statfs64',268)
SYS_stime = Constant('SYS_stime',25)
SYS_stty = Constant('SYS_stty',31)
SYS_swapoff = Constant('SYS_swapoff',115)
SYS_swapon = Constant('SYS_swapon',87)
SYS_symlink = Constant('SYS_symlink',83)
SYS_symlinkat = Constant('SYS_symlinkat',304)
SYS_sync = Constant('SYS_sync',36)
SYS_sync_file_range = Constant('SYS_sync_file_range',314)
SYS_syncfs = Constant('SYS_syncfs',344)
SYS__sysctl = Constant('SYS__sysctl',149)
SYS_sysfs = Constant('SYS_sysfs',135)
SYS_sysinfo = Constant('SYS_sysinfo',116)
SYS_sys_kexec_load = Constant('SYS_sys_kexec_load',283)
SYS_syslog = Constant('SYS_syslog',103)
SYS_tee = Constant('SYS_tee',315)
SYS_tgkill = Constant('SYS_tgkill',270)
SYS_time = Constant('SYS_time',13)
SYS_timer_create = Constant('SYS_timer_create',259)
SYS_timer_delete = Constant('SYS_timer_delete',(259+4))
SYS_timerfd = Constant('SYS_timerfd',322)
SYS_timerfd_gettime = Constant('SYS_timerfd_gettime',326)
SYS_timerfd_gettime64 = Constant('SYS_timerfd_gettime64',410)
SYS_timerfd_settime = Constant('SYS_timerfd_settime',325)
SYS_timerfd_settime64 = Constant('SYS_timerfd_settime64',411)
SYS_timer_getoverrun = Constant('SYS_timer_getoverrun',(259+3))
SYS_timer_gettime = Constant('SYS_timer_gettime',(259+2))
SYS_timer_gettime64 = Constant('SYS_timer_gettime64',408)
SYS_timer_settime = Constant('SYS_timer_settime',(259+1))
SYS_timer_settime64 = Constant('SYS_timer_settime64',409)
SYS_times = Constant('SYS_times',43)
SYS_tkill = Constant('SYS_tkill',238)
SYS_truncate = Constant('SYS_truncate',92)
SYS_truncate64 = Constant('SYS_truncate64',193)
SYS_ugetrlimit = Constant('SYS_ugetrlimit',191)
SYS_ulimit = Constant('SYS_ulimit',58)
SYS_umask = Constant('SYS_umask',60)
SYS_umount = Constant('SYS_umount',22)
SYS_umount2 = Constant('SYS_umount2',52)
SYS_uname = Constant('SYS_uname',122)
SYS_unlink = Constant('SYS_unlink',10)
SYS_unlinkat = Constant('SYS_unlinkat',301)
SYS_unshare = Constant('SYS_unshare',310)
SYS_uselib = Constant('SYS_uselib',86)
SYS_userfaultfd = Constant('SYS_userfaultfd',374)
SYS_ustat = Constant('SYS_ustat',62)
SYS_utime = Constant('SYS_utime',30)
SYS_utimensat = Constant('SYS_utimensat',320)
SYS_utimensat_time64 = Constant('SYS_utimensat_time64',412)
SYS_utimes = Constant('SYS_utimes',271)
SYS_vfork = Constant('SYS_vfork',190)
SYS_vhangup = Constant('SYS_vhangup',111)
SYS_vm86 = Constant('SYS_vm86',166)
SYS_vm86old = Constant('SYS_vm86old',113)
SYS_vmsplice = Constant('SYS_vmsplice',316)
SYS_vserver = Constant('SYS_vserver',273)
SYS_wait4 = Constant('SYS_wait4',114)
SYS_waitid = Constant('SYS_waitid',284)
SYS_waitpid = Constant('SYS_waitpid',7)
SYS_write = Constant('SYS_write',4)
SYS_writev = Constant('SYS_writev',146)
SYS_socketcall_socket = Constant('SYS_socketcall_socket',1)
SYS_socketcall_bind = Constant('SYS_socketcall_bind',2)
SYS_socketcall_connect = Constant('SYS_socketcall_connect',3)
SYS_socketcall_listen = Constant('SYS_socketcall_listen',4)
SYS_socketcall_accept = Constant('SYS_socketcall_accept',5)
SYS_socketcall_getsockname = Constant('SYS_socketcall_getsockname',6)
SYS_socketcall_getpeername = Constant('SYS_socketcall_getpeername',7)
SYS_socketcall_socketpair = Constant('SYS_socketcall_socketpair',8)
SYS_socketcall_send = Constant('SYS_socketcall_send',9)
SYS_socketcall_recv = Constant('SYS_socketcall_recv',10)
SYS_socketcall_sendto = Constant('SYS_socketcall_sendto',11)
SYS_socketcall_recvfrom = Constant('SYS_socketcall_recvfrom',12)
SYS_socketcall_shutdown = Constant('SYS_socketcall_shutdown',13)
SYS_socketcall_setsockopt = Constant('SYS_socketcall_setsockopt',14)
SYS_socketcall_getsockopt = Constant('SYS_socketcall_getsockopt',15)
SYS_socketcall_sendmsg = Constant('SYS_socketcall_sendmsg',16)
SYS_socketcall_recvmsg = Constant('SYS_socketcall_recvmsg',17)



from __future__ import division

import re

from pygments.lexer import DelegatingLexer
from pygments.lexer import RegexLexer
from pygments.lexer import bygroups
from pygments.lexer import include
from pygments.lexer import using
from pygments.lexers.c_cpp import CLexer
from pygments.lexers.c_cpp import CppLexer
from pygments.lexers.d import DLexer
from pygments.token import Comment
from pygments.token import Keyword
from pygments.token import Name
from pygments.token import Number
from pygments.token import Operator
from pygments.token import Other
from pygments.token import Punctuation
from pygments.token import String
from pygments.token import Text

__all__ = ['GasLexer', 'ObjdumpLexer', 'DObjdumpLexer', 'CppObjdumpLexer',
           'CObjdumpLexer', 'LlvmLexer', 'NasmLexer', 'NasmObjdumpLexer',
           'Ca65Lexer']


class PwntoolsLexer(RegexLexer):
    """
    For Gas (AT&T) assembly code.
    """
    name = 'GAS'
    aliases = ['gas', 'asm']
    filenames = ['*.s', '*.S', '*.asm']
    mimetypes = ['text/x-gas']

    #: optional Comment or Whitespace
    string = r'"(\\"|[^"])*"'
    char = r'[\w$.@-]'
    identifier = r'(?:[a-zA-Z$_]' + char + r'*|\.' + char + '+|or)'
    number = r'(?:-?0[xX][a-zA-Z0-9]+|\d+)'
    memory = r'(?:[\]\[])'
    bad = r'(?:\(bad\))'

    tokens = {
        'root': [
            include('whitespace'),
            (identifier + ':', Name.Label),
            (r'\.' + identifier, Name.Attribute, 'directive-args'),
            (r'lock|rep(n?z)?|data\d+', Name.Attribute),
            (identifier, Name.Function, 'instruction-args'),
            (r'[\r\n]+', Text),
            (bad, Text)
        ],

        'directive-args': [
            (identifier, Name.Constant),
            (string, String),
            ('@' + identifier, Name.Attribute),
            (number, Number.Integer),
            (r'[\r\n]+', Text, '#pop'),

            (r'#.*?$', Comment, '#pop'),

            include('punctuation'),
            include('whitespace')
        ],
        'instruction-args': [
            # For objdump-disassembled code, shouldn't occur in
            # actual assembler input
            ('([a-z0-9]+)( )(<)('+identifier+')(>)',
                bygroups(Number.Hex, Text, Punctuation, Name.Constant,
                         Punctuation)),
            ('([a-z0-9]+)( )(<)('+identifier+')([-+])('+number+')(>)',
                bygroups(Number.Hex, Text, Punctuation, Name.Constant,
                         Punctuation, Number.Integer, Punctuation)),

            # Fun things
            (r'([\]\[]|BYTE|DWORD|PTR|\+|\-|}|{|\^|>>|<<|&)', Text),

            # Address constants
            (identifier, Name.Constant),
            (number, Number.Integer),
            # Registers
            ('%' + identifier, Name.Variable),
            ('$' + identifier, Name.Variable),
            # Numeric constants
            ('$'+number, Number.Integer),
            ('#'+number, Number.Integer),
            (r"$'(.|\\')'", String.Char),
            (r'[\r\n]+', Text, '#pop'),
            include('punctuation'),
            include('whitespace')
        ],
        'whitespace': [
            (r'\n', Text),
            (r'\s+', Text),
            (r'/\*.*?\*/', Comment),
            (r';.*$', Comment)
        ],
        'punctuation': [
            (r'[-*,.():]+', Punctuation)
        ]
    }

    def analyse_text(text):
        if re.match(r'^\.(text|data|section)', text, re.M):
            return True
        elif re.match(r'^\.\w+', text, re.M):
            return 0.1




class Device(object):
    arch = None
    bits = None
    endian = None
    serial = None
    os = None

    def __init__(self, serial=None):
        self.serial = serial

    def __str__(self):
        return self.serial

    def __eq__(self, other):
        return self.serial == other or self.serial == str(other)



# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import division

import collections
import random
import re
import string

from pwnlib.context import LocalContext
from pwnlib.context import context
from pwnlib.log import getLogger
from pwnlib.util.fiddling import hexdump

log = getLogger(__name__)

class Encoder(object):
    _encoders = collections.defaultdict(lambda: [])

    #: Architecture which this encoder works on
    arch = None

    #: Blacklist of bytes which are known not to be supported
    blacklist = set()

    def __init__(self):
        """Shellcode encoder class

        Implements an architecture-specific shellcode encoder
        """
        Encoder._encoders[self.arch].append(self)

    def __call__(self, raw_bytes, avoid, pcreg):
        """avoid(raw_bytes, avoid)

        Arguments:
            raw_bytes(str):
                String of bytes to encode
            avoid(set):
                Set of bytes to avoid
            pcreg(str):
                Register which contains the address of the shellcode.
                May be necessary for some shellcode.
        """
        raise NotImplementedError()


@LocalContext
def encode(raw_bytes, avoid=None, expr=None, force=0, pcreg=''):
    """encode(raw_bytes, avoid, expr, force) -> str

    Encode shellcode ``raw_bytes`` such that it does not contain
    any bytes in ``avoid`` or ``expr``.

    Arguments:

        raw_bytes(str): Sequence of shellcode bytes to encode.
        avoid(str):     Bytes to avoid
        expr(str):      Regular expression which matches bad characters.
        force(bool):    Force re-encoding of the shellcode, even if it
                        doesn't contain any bytes in ``avoid``.
    """
    orig_avoid = avoid

    avoid = set(avoid or '')

    if expr:
        for char in all_chars:
            if re.search(expr, char):
                avoid.add(char)

    if not (force or avoid & set(raw_bytes)):
        return raw_bytes

    encoders = Encoder._encoders[context.arch]
    random.shuffle(encoders)

    for encoder in encoders:
        if encoder.blacklist & avoid:
            continue

        try:
            v = encoder(raw_bytes, bytes(avoid), pcreg)
        except NotImplementedError:
            continue

        if avoid & set(v):
            log.warning_once("Encoder %s did not succeed" % encoder)
            continue

        return v


    avoid_errmsg = ''
    if orig_avoid and expr:
        avoid_errmsg = '%r and %r' % (orig_avoid, expr)
    elif expr:
        avoid_errmsg = repr(expr)
    else:
        avoid_errmsg = repr(bytes(avoid))

    args = (context.arch, avoid_errmsg, hexdump(raw_bytes))
    msg = "No encoders for %s which can avoid %s for\n%s" % args
    msg = msg.replace('%', '%%')
    log.error(msg)

all_chars        = list(chr(i) for i in range(256))
re_alphanumeric  = r'[^A-Za-z0-9]'
re_printable     = r'[^\x21-\x7e]'
re_whitespace    = r'\s'
re_null          = r'\x00'
re_line          = r'[\s\x00]'

@LocalContext
def null(raw_bytes, *a, **kw):
    """null(raw_bytes) -> str

    Encode the shellcode ``raw_bytes`` such that it does not
    contain any NULL bytes.

    Accepts the same arguments as :func:`encode`.
    """
    return encode(raw_bytes, expr=re_null, *a, **kw)

@LocalContext
def line(raw_bytes, *a, **kw):
    """line(raw_bytes) -> str

    Encode the shellcode ``raw_bytes`` such that it does not
    contain any NULL bytes or whitespace.

    Accepts the same arguments as :func:`encode`.
    """
    return encode(raw_bytes, expr=re_whitespace, *a, **kw)

@LocalContext
def alphanumeric(raw_bytes, *a, **kw):
    """alphanumeric(raw_bytes) -> str

    Encode the shellcode ``raw_bytes`` such that it does not
    contain any bytes except for [A-Za-z0-9].

    Accepts the same arguments as :func:`encode`.
    """
    return encode(raw_bytes, expr=re_alphanumeric, *a, **kw)

@LocalContext
def printable(raw_bytes, *a, **kw):
    """printable(raw_bytes) -> str

    Encode the shellcode ``raw_bytes`` such that it only contains
    non-space printable bytes.

    Accepts the same arguments as :func:`encode`.
    """
    return encode(raw_bytes, expr=re_printable, *a, **kw)

@LocalContext
def scramble(raw_bytes, *a, **kw):
    """scramble(raw_bytes) -> str

    Encodes the input data with a random encoder.

    Accepts the same arguments as :func:`encode`.
    """
    return encode(raw_bytes, force=1, *a, **kw)



"""
Pwntools exposes several magic command-line arguments and environment
variables when operating in `from pwn import *` mode.

The arguments extracted from the command-line and removed from ``sys.argv``.

Arguments can be set by appending them to the command-line, or setting
them in the environment prefixed by ``PWNLIB_``.

The easiest example is to enable more verbose debugging.  Just set ``DEBUG``.

.. code-block:: bash

    $ PWNLIB_DEBUG=1 python exploit.py
    $ python exploit.py DEBUG

These arguments are automatically extracted, regardless of their name, and
exposed via :mod:`pwnlib.args.args`, which is exposed as the global variable
:data:`args`.  Arguments which ``pwntools`` reserves internally are not exposed
this way.

.. code-block:: bash

    $ python -c 'from pwn import *; print(args)' A=1 B=Hello HOST=1.2.3.4 DEBUG
    defaultdict(<type 'str'>, {'A': '1', 'HOST': '1.2.3.4', 'B': 'Hello'})

This is very useful for conditional code, for example determining whether to
run an exploit locally or to connect to a remote server.  Arguments which are
not specified evaluate to an empty string.

.. code-block:: python

    if args['REMOTE']:
        io = remote('exploitme.com', 4141)
    else:
        io = process('./pwnable')

Arguments can also be accessed directly with the dot operator, e.g.:

.. code-block:: python

    if args.REMOTE:
        ...

Any undefined arguments evaluate to an empty string, ``''``.

The full list of supported "magic arguments" and their effects are listed
below.

"""
from __future__ import absolute_import
from __future__ import division

import collections
import logging
import os
import string
import sys

from pwnlib import term
from pwnlib.context import context

class PwnlibArgs(collections.defaultdict):
    def __getattr__(self, attr):
        if attr.startswith('_'):
            raise AttributeError(attr)
        return self[attr]

args = PwnlibArgs(str)
term_mode  = True
env_prefix = 'PWNLIB_'
free_form  = True

# Check to see if we were invoked as one of the 'pwn xxx' scripts.
# If so, we don't want to remove e.g. "SYS_" from the end of the command
# line, as this breaks things like constgrep.
import pwnlib.commandline
basename = os.path.basename(sys.argv[0])

if basename == 'pwn' or basename in pwnlib.commandline.__all__:
    free_form = False


def isident(s):
    """
    Helper function to check whether a string is a valid identifier,
    as passed in on the command-line.
    """
    first = string.ascii_uppercase + '_'
    body = string.digits + first
    if not s:
        return False
    if s[0] not in first:
        return False
    if not all(c in body for c in s[1:]):
        return False
    return True

def asbool(s):
    """
    Convert a string to its boolean value
    """
    if   s.lower() == 'true':
        return True
    elif s.lower() == 'false':
        return False
    elif s.isdigit():
        return bool(int(s))
    else:
        raise ValueError('must be integer or boolean: %r' % s)

def LOG_LEVEL(x):
    """Sets the logging verbosity used via ``context.log_level``,
    e.g. ``LOG_LEVEL=debug``.
    """
    with context.local(log_level=x):
        context.defaults['log_level']=context.log_level

def LOG_FILE(x):
    """Sets a log file to be used via ``context.log_file``, e.g.
    ``LOG_FILE=./log.txt``"""
    context.log_file=x

def SILENT(x):
    """Sets the logging verbosity to ``error`` which silences most
    output."""
    LOG_LEVEL('error')

def DEBUG(x):
    """Sets the logging verbosity to ``debug`` which displays much
    more information, including logging each byte sent by tubes."""
    LOG_LEVEL('debug')

def NOTERM(v):
    """Disables pretty terminal settings and animations."""
    if asbool(v):
        global term_mode
        term_mode = False

def TIMEOUT(v):
    """Sets a timeout for tube operations (in seconds) via
    ``context.timeout``, e.g. ``TIMEOUT=30``"""
    context.defaults['timeout'] = int(v)

def RANDOMIZE(v):
    """Enables randomization of various pieces via ``context.randomize``"""
    context.defaults['randomize'] = asbool(v)

def NOASLR(v):
    """Disables ASLR via ``context.aslr``"""
    context.defaults['aslr'] = not asbool(v)

def NOPTRACE(v):
    """Disables facilities which require ``ptrace`` such as ``gdb.attach()``
    statements, via ``context.noptrace``."""
    context.defaults['noptrace'] = asbool(v)

def STDERR(v):
    """Sends logging to ``stderr`` by default, instead of ``stdout``"""
    context.log_console = sys.stderr

def LOCAL_LIBCDB(v):
    """Sets path to local libc-database via ``context.local_libcdb``, e.g. 
    ``LOCAL_LIBCDB='/path/to/libc-databse'``"""
    context.local_libcdb = v

hooks = {
    'LOG_LEVEL': LOG_LEVEL,
    'LOG_FILE': LOG_FILE,
    'DEBUG': DEBUG,
    'NOTERM': NOTERM,
    'SILENT': SILENT,
    'RANDOMIZE': RANDOMIZE,
    'TIMEOUT': TIMEOUT,
    'NOASLR': NOASLR,
    'NOPTRACE': NOPTRACE,
    'STDERR': STDERR,
    'LOCAL_LIBCDB': LOCAL_LIBCDB,
}

def initialize():
    global args, term_mode

    # Hack for readthedocs.org
    if 'READTHEDOCS' in os.environ:
        os.environ['PWNLIB_NOTERM'] = '1'

    for k, v in os.environ.items():
        if not k.startswith(env_prefix):
            continue
        k = k[len(env_prefix):]

        if k in hooks:
            hooks[k](v)
        elif isident(k):
            args[k] = v

    argv = sys.argv[:]
    for arg in sys.argv[:]:
        orig  = arg
        value = 'True'

        if '=' in arg:
            arg, value = arg.split('=', 1)

        if arg in hooks:
            sys.argv.remove(orig)
            hooks[arg](value)

        elif free_form and isident(arg):
            sys.argv.remove(orig)
            args[arg] = value

    if term_mode:
        term.init()



'''
Example showing how to use `pwnlib.term.text`.

Try running with::

  $ TERM=xterm python text.py

and::

  $ TERM=xterm-256color python text.py
'''
from pwn import *

s = 'hello from pwntools'
print(text.black_on_green(s))
print(text.black_on_bright_green(s))
print(text.green_on_black(s))
print(text.bright_green_on_black(s))
print(text.bold_green_on_black(s))



"""
Simple example showing how to use the remote
gdb debugging features available in pwntools.
"""

import getpass

from pwn import *

s = ssh(getpass.getuser(), '127.0.0.1', port = 22, keyfile = "~/.ssh/id_rsa")
c = gdb.ssh_gdb(s, '/bin/sh', gdbscript = '''
p/x $pc
c''')

c.sendline('ls -la')
c.sendline('exit')
print(c.recvall())



from __future__ import absolute_import
from __future__ import division

import glob
import platform
import sys
import time

import serial

from pwnlib.log import getLogger
from pwnlib.tubes import tube

log = getLogger(__name__)

class serialtube(tube.tube):
    def __init__(
            self, port = None, baudrate = 115200,
            convert_newlines = True,
            bytesize = 8, parity='N', stopbits=1, xonxoff = False,
            rtscts = False, dsrdtr = False, *a, **kw):
        super(serialtube, self).__init__(*a, **kw)

        if port is None:
            if platform.system() == 'Darwin':
                port = glob.glob('/dev/tty.usbserial*')[0]
            else:
                port = '/dev/ttyUSB0'

        self.convert_newlines = convert_newlines
        # serial.Serial might throw an exception, which must be handled
        # and propagated accordingly using self.exception
        try:
            self.conn = serial.Serial(
                port = port,
                baudrate = baudrate,
                bytesize = bytesize,
                parity = parity,
                stopbits = stopbits,
                timeout = 0,
                xonxoff = xonxoff,
                rtscts = rtscts,
                writeTimeout = None,
                dsrdtr = dsrdtr,
                interCharTimeout = 0
            )
        except serial.SerialException:
            # self.conn is set to None to avoid an AttributeError when
            # initialization fails, but the program still tries closing
            # the serial tube anyway
            self.conn = None
            self.exception("Could not open a serial tube on port %s", port)

    # Implementation of the methods required for tube
    def recv_raw(self, numb):
        if not self.conn:
            raise EOFError

        with self.countdown():
            while self.conn and self.countdown_active():
                data = self.conn.read(numb)

                if data:
                    return data

                time.sleep(min(self.timeout, 0.1))

        return None

    def send_raw(self, data):
        if not self.conn:
            raise EOFError

        if self.convert_newlines:
            data = data.replace(b'\n', b'\r\n')

        while data:
            n = self.conn.write(data)
            data = data[n:]
        self.conn.flush()

    def settimeout_raw(self, timeout):
        pass

    def can_recv_raw(self, timeout):
        with self.countdown(timeout):
            while self.conn and self.countdown_active():
                if self.conn.inWaiting():
                    return True
                time.sleep(min(self.timeout, 0.1))
        return False

    def connected_raw(self, direction):
        return self.conn is not None

    def close(self):
        if self.conn:
            self.conn.close()
            self.conn = None

    def fileno(self):
        if not self.connected():
            self.error("A closed serialtube does not have a file number")

        return self.conn.fileno()

    def shutdown_raw(self, direction):
        self.close()



from __future__ import absolute_import
from __future__ import division

import argparse
import sys

from pwn import *
from pwnlib.commandline import common

parser = common.parser_commands.add_parser(
    'checksec',
    help = 'Check binary security settings',
    description = 'Check binary security settings',
)
parser.add_argument(
    'elf',
    nargs='*',
    type=argparse.FileType('rb'),
    help='Files to check'
)
parser.add_argument(
    '--file',
    nargs='*',
    dest='elf2',
    metavar='elf',
    type=argparse.FileType('rb'),
    help='File to check (for compatibility with checksec.sh)'
)

def main(args):
    files  = args.elf or args.elf2 or []

    if not files:
        parser.print_usage()
        return

    for f in files:
        try:
            e = ELF(f.name)
        except Exception as e:
            print("{name}: {error}".format(name=f.name, error=e))

if __name__ == '__main__':
    common.main(__file__, main)



# -*- coding: utf-8 -*-
"""
Timeout encapsulation, complete with countdowns and scope managers.
"""
from __future__ import division

import time

import pwnlib


class _DummyContextClass(object):
    def __enter__(self):   pass
    def __exit__(self,*a): pass

_DummyContext = _DummyContextClass()

class _countdown_handler(object):
    def __init__(self, obj, timeout):
        self.obj     = obj
        self.timeout = timeout

    def __enter__(self):
        self.old_timeout  = self.obj._timeout
        self.old_stop     = self.obj._stop

        self.obj._stop    = time.time() + self.timeout

        if self.old_stop:
            self.obj._stop = min(self.obj._stop, self.old_stop)

        self.obj._timeout = self.timeout
        self.obj.timeout_change()
    def __exit__(self, *a):
        self.obj._timeout = self.old_timeout
        self.obj._stop    = self.old_stop
        self.obj.timeout_change()

class _local_handler(object):
    def __init__(self, obj, timeout):
        self.obj     = obj
        self.timeout = timeout
    def __enter__(self):
        self.old_timeout  = self.obj._timeout
        self.old_stop     = self.obj._stop

        self.obj._stop    = 0
        self.obj._timeout = self.timeout # leverage validation
        self.obj.timeout_change()

    def __exit__(self, *a):
        self.obj._timeout = self.old_timeout
        self.obj._stop    = self.old_stop
        self.obj.timeout_change()

class TimeoutDefault(object):
    def __repr__(self): return "pwnlib.timeout.Timeout.default"
    def __str__(self): return "<default timeout>"

class Maximum(float):
    def __repr__(self):
        return 'pwnlib.timeout.maximum'
maximum = Maximum(2**20)

class Timeout(object):
    """
    Implements a basic class which has a timeout, and support for
    scoped timeout countdowns.

    Valid timeout values are:

    - ``Timeout.default`` use the global default value (``context.default``)
    - ``Timeout.forever`` or :const:`None` never time out
    - Any positive float, indicates timeouts in seconds

    Example:

        >>> context.timeout = 30
        >>> t = Timeout()
        >>> t.timeout == 30
        True
        >>> t = Timeout(5)
        >>> t.timeout == 5
        True
        >>> i = 0
        >>> with t.countdown():
        ...     print(4 <= t.timeout and t.timeout <= 5)
        ...
        True
        >>> with t.countdown(0.5): # doctest: +ELLIPSIS
        ...     while t.timeout:
        ...         print(round(t.timeout,1))
        ...         time.sleep(0.1)
        0.5
        0.4
        0.3
        0.2
        0.1
        >>> print(t.timeout)
        5.0
        >>> with t.local(0.5):# doctest: +ELLIPSIS
        ...     for i in range(5):
        ...         print(round(t.timeout,1))
        ...         time.sleep(0.1)
        0.5
        0.5
        0.5
        0.5
        ...
        >>> print(t.timeout)
        5.0
    """


    #: Value indicating that the timeout should not be changed
    default = TimeoutDefault()

    #: Value indicating that a timeout should not ever occur
    forever = None

    #: Maximum value for a timeout.  Used to get around platform issues
    #: with very large timeouts.
    #:
    #: OSX does not permit setting socket timeouts to 2**22.
    #: Assume that if we receive a timeout of 2**21 or greater,
    #: that the value is effectively infinite.
    maximum = maximum

    def __init__(self, timeout=default):
        self._stop    = 0
        self.timeout = self._get_timeout_seconds(timeout)

    @property
    def timeout(self):
        """
        Timeout for obj operations.  By default, uses ``context.timeout``.
        """
        timeout = self._timeout
        stop    = self._stop

        if not stop:
            return timeout

        return max(stop-time.time(), 0)

    @timeout.setter
    def timeout(self, value):
        assert not self._stop
        self._timeout = self._get_timeout_seconds(value)
        self.timeout_change()

    def _get_timeout_seconds(self, value):
        if value is self.default:
            value = pwnlib.context.context.timeout

        elif value is self.forever:
            value = self.maximum

        else:
            value = float(value)

            if value < 0:
                raise AttributeError("timeout: Timeout cannot be negative")

            if value > self.maximum:
                value = self.maximum
        return value

    def countdown_active(self):
        return (self._stop == 0) or (self._stop > time.time())

    def timeout_change(self):
        """
        Callback for subclasses to hook a timeout change.
        """
        pass

    def countdown(self, timeout = default):
        """
        Scoped timeout setter.  Sets the timeout within the scope,
        and restores it when leaving the scope.

        When accessing :attr:`timeout` within the scope, it will be
        calculated against the time when the scope was entered, in a
        countdown fashion.

        If :const:`None` is specified for ``timeout``, then the current
        timeout is used is made.  This allows :const:`None` to be specified
        as a default argument with less complexity.
        """
        # Don't count down from infinity
        if timeout is self.maximum:
            return _DummyContext

        if timeout is self.default and self.timeout is self.maximum:
            return _DummyContext

        if timeout is self.default:
            timeout = self._timeout

        return _countdown_handler(self, timeout)

    def local(self, timeout):
        """
        Scoped timeout setter.  Sets the timeout within the scope,
        and restores it when leaving the scope.
        """
        if timeout is self.default or timeout == self.timeout:
            return _DummyContext

        return _local_handler(self, timeout)



"""
Replacement for the Python standard library's atexit.py.

Whereas the standard :mod:`atexit` module only defines :func:`atexit.register`,
this replacement module also defines :func:`unregister`.

This module also fixes a the issue that exceptions raised by an exit handler is
printed twice when the standard :mod:`atexit` is used.
"""
from __future__ import absolute_import
from __future__ import division

import sys
import threading
import traceback
import atexit as std_atexit

from pwnlib.context import context

__all__ = ['register', 'unregister']

_lock = threading.Lock()
_ident = 0
_handlers = {}

def register(func, *args, **kwargs):
    """register(func, *args, **kwargs)

    Registers a function to be called on program termination.  The function will
    be called with positional arguments `args` and keyword arguments `kwargs`,
    i.e. ``func(*args, **kwargs)``.  The current `context` is recorded and will
    be the one used when the handler is run.

    E.g. to suppress logging output from an exit-handler one could write::

      with context.local(log_level = 'error'):
        atexit.register(handler)

    An identifier is returned which can be used to unregister the exit-handler.

    This function can be used as a decorator::

      @atexit.register
      def handler():
        ...

    Notice however that this will bind ``handler`` to the identifier and not the
    actual exit-handler.  The exit-handler can then be unregistered with::

      atexit.unregister(handler)

    This function is thread safe.

    """
    global _ident
    with _lock:
        ident = _ident
        _ident += 1
    _handlers[ident] = (func, args, kwargs, vars(context))
    return ident

def unregister(ident):
    """unregister(ident)

    Remove the exit-handler identified by `ident` from the list of registered
    handlers.  If `ident` isn't registered this is a no-op.
    """
    if ident in _handlers:
        del _handlers[ident]

def _run_handlers():
    """_run_handlers()

    Run registered exit-handlers.  They run in the reverse order of which they
    were registered.

    If a handler raises an exception, it will be printed but nothing else
    happens, i.e. other handlers will be run and `sys.excepthook` will not be
    called for that reason.
    """
    context.clear()
    for _ident, (func, args, kwargs, ctx) in \
        sorted(_handlers.items(), reverse = True):
        try:
            with context.local(**ctx):
                func(*args, **kwargs)
        except SystemExit:
            pass
        except Exception:
            # extract the current exception and rewind the traceback to where it
            # originated
            typ, val, tb = sys.exc_info()
            traceback.print_exception(typ, val, tb.tb_next)

# if there's already an exitfunc registered be sure to run that too
if hasattr(sys, "exitfunc"):
    register(sys.exitfunc)

if sys.version_info[0] < 3:
    sys.exitfunc = _run_handlers
else:
    std_atexit.register(_run_handlers)




from __future__ import absolute_import
from __future__ import division

import socket
import socks

from pwnlib.log import getLogger
from pwnlib.timeout import Timeout
from pwnlib.tubes.sock import sock

log = getLogger(__name__)

class remote(sock):
    r"""Creates a TCP or UDP-connection to a remote host. It supports
    both IPv4 and IPv6.

    The returned object supports all the methods from
    :class:`pwnlib.tubes.sock` and :class:`pwnlib.tubes.tube`.

    Arguments:
        host(str): The host to connect to.
        port(int): The port to connect to.
        fam: The string "any", "ipv4" or "ipv6" or an integer to pass to :func:`socket.getaddrinfo`.
        typ: The string "tcp" or "udp" or an integer to pass to :func:`socket.getaddrinfo`.
        timeout: A positive number, None or the string "default".
        sock(:class:`socket.socket`): Socket to inherit, rather than connecting
        ssl(bool): Wrap the socket with SSL
        ssl_context(ssl.SSLContext): Specify SSLContext used to wrap the socket.
        ssl_args(dict): Pass :func:`ssl.wrap_socket` named arguments in a dictionary.
        sni(str,bool): Set 'server_hostname' in ssl_args. Set to True to set it based on the host argument. Set to False to not provide any value. Default is True.

    Examples:

        >>> r = remote('google.com', 443, ssl=True)
        >>> r.send(b'GET /\r\n\r\n')
        >>> r.recvn(4)
        b'HTTP'

        If a connection cannot be made, an exception is raised.

        >>> r = remote('127.0.0.1', 1)
        Traceback (most recent call last):
        ...
        PwnlibException: Could not connect to 127.0.0.1 on port 1

        You can also use :meth:`.remote.fromsocket` to wrap an existing socket.

        >>> import socket
        >>> s = socket.socket()
        >>> s.connect(('google.com', 80))
        >>> s.send(b'GET /' + b'\r\n'*2)
        9
        >>> r = remote.fromsocket(s)
        >>> r.recvn(4)
        b'HTTP'
        >>> s = socket.socket(socket.AF_INET6, socket.SOCK_STREAM) #doctest: +SKIP
        >>> s.connect(('2606:4700:4700::1111', 80)) #doctest: +SKIP
        >>> s.send(b'GET ' + b'\r\n'*2) #doctest: +SKIP
        8
        >>> r = remote.fromsocket(s) #doctest: +SKIP
        >>> r.recvn(4) #doctest: +SKIP
        b'HTTP'
    """

    def __init__(self, host, port,
                 fam = "any", typ = "tcp",
                 sock=None, ssl=False, ssl_context=None, ssl_args=None, sni=True,
                 *args, **kwargs):
        super(remote, self).__init__(*args, **kwargs)

        # convert port to string for sagemath support
        self.rport  = str(port)
        self.rhost  = host

        if sock:
            self.family = sock.family
            self.type   = sock.type
            self.proto  = sock.proto
            self.sock   = sock

        else:
            typ = self._get_type(typ)
            fam = self._get_family(fam)
            try:
                self.sock   = self._connect(fam, typ)
            except socket.gaierror as e:
                if e.errno != socket.EAI_NONAME:
                    raise
                self.error('Could not resolve hostname: %r', host)
        if self.sock:
            self.settimeout(self.timeout)
            self.lhost, self.lport = self.sock.getsockname()[:2]

            if ssl:
                # Deferred import to save startup time
                import ssl as _ssl

                ssl_args = ssl_args or {}
                if "server_hostname" in ssl_args and sni:
                    log.error("sni and server_hostname cannot be set at the same time")
                ssl_context = ssl_context or _ssl.SSLContext(_ssl.PROTOCOL_TLSv1_2)
                if isinstance(sni, str):
                    ssl_args["server_hostname"] = sni
                elif sni:
                    ssl_args["server_hostname"] = host
                self.sock = ssl_context.wrap_socket(self.sock,**ssl_args)

    def _connect(self, fam, typ):
        sock    = None
        timeout = self.timeout

        with self.waitfor('Opening connection to %s on port %s' % (self.rhost, self.rport)) as h:
            for res in socket.getaddrinfo(self.rhost, self.rport, fam, typ, 0, socket.AI_PASSIVE):
                self.family, self.type, self.proto, _canonname, sockaddr = res

                if self.type not in [socket.SOCK_STREAM, socket.SOCK_DGRAM]:
                    continue

                h.status("Trying %s", sockaddr[0])

                sock = socket.socket(self.family, self.type, self.proto)

                if timeout is not None and timeout <= 0:
                    sock.setblocking(0)
                else:
                    sock.setblocking(1)
                    sock.settimeout(timeout)

                try:
                    sock.connect(sockaddr)
                    return sock
                except socks.ProxyError:
                    raise
                except socket.error:
                    pass
            self.error("Could not connect to %s on port %s", self.rhost, self.rport)

    @classmethod
    def fromsocket(cls, socket):
        """
        Helper method to wrap a standard python socket.socket with the
        tube APIs.

        Arguments:
            socket: Instance of socket.socket

        Returns:
            Instance of pwnlib.tubes.remote.remote.
        """
        s = socket
        host, port = s.getpeername()[:2]
        return remote(host, port, fam=s.family, typ=s.type, sock=s)

class tcp(remote):
    __doc__ = remote.__doc__
    def __init__(self, host, port, *a, **kw):
        return super(tcp, self).__init__(host, port, typ="tcp", *a, **kw)

class udp(remote):
    __doc__ = remote.__doc__
    def __init__(self, host, port, *a, **kw):
        return super(udp, self).__init__(host, port, typ="udp", *a, **kw)

class connect(remote):
    __doc__ = remote.__doc__
